@@ -3,7 +3,6 @@
 from __future__ import annotations
 
 import asyncio
-import functools
 import io
 from collections import defaultdict
 from copy import deepcopy
@@ -26,11 +25,9 @@ from opendapi.utils import (
     async_backoff_retry,
     create_session_with_retries,
     dump_dict_to_yaml_str,
-    has_dapi_file_materially_changed,
-    has_underlying_model_changed,
     make_api_w_query_and_body,
 )
-from opendapi.validators.defs import CollectedFile
+from opendapi.validators.defs import CollectedFile, OpenDAPIEntityCICDMetadata
 
 TOTAL_RETRIES = 5
 RETRY_BACKOFF_FACTOR = 10
@@ -78,225 +75,6 @@ class DAPIServerRequestType(Enum):
     CICD_GET_MISSING_DAPIS = "/v2/cicd/dapi/missing"
 
 
-@dataclass
-class OpenDAPIEntityCICDMetadata:
-    """Metadata for OpenDAPI entities"""
-
-    entity: OpenDAPIEntity
-    # NOTE: make sure this is formatted for the server!
-    filepath: str
-    # NOTE: decide if here post init we make sure that
-    # head cannot be skipped generate if base wasnt?
-    # I think that makes sense...
-    base_collect: CollectedFile | None
-    head_collect: CollectedFile | None
-    integration_mode: str
-
-    @functools.cached_property
-    def entity_changed_from_base(self) -> bool:
-        """Check if the model is changed from the model state at base."""
-        # for a non-dapi file, any change to the **file** state from base
-        # is considered a change
-        if self.entity is not OpenDAPIEntity.DAPI:
-            return (self.base_collect and self.base_collect.original) != (
-                self.head_collect and self.head_collect.merged
-            )
-
-        # we note that the file can remain after the entity is deleted
-        # in that case any file differences arent actual entity changes
-        base_generated = self.base_collect.generated if self.base_collect else None
-        head_generated = self.head_collect.generated if self.head_collect else None
-        if not base_generated and not head_generated:
-            return False
-
-        # if it exists in one but not the other, then surely it was changed
-        if bool(base_generated) != bool(head_generated):
-            return True
-
-        # entity exists at both, so we compare if there were any meaningful changes.
-        # note that we compare merged - but prune it - so that nullability
-        # changes are considered changes
-        base_merged = self.base_collect.merged if self.base_collect else None
-        head_merged = self.head_collect.merged if self.head_collect else None
-
-        return has_underlying_model_changed(base_merged, head_merged)
-
-    @property
-    def entity_is_new(self) -> bool:
-        """Check if the model is new"""
-        # we do these gymnastics since the dapi file can remain after the entity
-        # is deleted
-        base_generated = self.base_collect.generated if self.base_collect else None
-        return self.entity_changed_from_base and not base_generated
-
-    @property
-    def entity_is_deprecated(self) -> bool:
-        """Check if the model is deprecated"""
-        head_generated = self.head_collect.generated if self.head_collect else None
-        return self.entity_changed_from_base and not head_generated
-
-    # NOTE: entity cannot be changed from head, since we do not
-    #       ever change anything at the ORM level
-
-    @property
-    def file_git_tracked(self) -> bool:
-        """
-        Check if the file is tracked by git
-        determined if the file ever existed
-        """
-        return (
-            self.head_collect is not None and self.head_collect.original is not None
-        ) or (self.base_collect is not None and self.base_collect.original is not None)
-
-    @functools.cached_property
-    def _should_be_processed(self) -> Tuple[bool, str]:
-        """Check if the entity should be processed"""
-        # in shadow mode, we only run CICD if the dapi was onboarded
-        # or is being onboarded
-        # note about possibly doing something else for enrich
-        # during shadow for a diff experience
-        in_shadow_mode = self.integration_mode == "shadow"
-        if in_shadow_mode and not self.file_git_tracked:
-            return False, "SHADOW_MODE_AND_FILE_NOT_TRACKED"
-
-        # the entity and file are not at head (therefore at least one is at base).
-        # this is because either the model was just deleted, or both
-        # the model and the dapi were just deleted. regardless,
-        # there is nothing to check
-        if not self.head_collect:
-            return False, "ENTITY_AND_FILE_NOT_AT_HEAD"
-
-        # first we handle non DAPI cases
-        # any file changes from be processed
-        if self.entity is not OpenDAPIEntity.DAPI:
-            # if the **file** didnt exist and now exists in any capacity,
-            # we need to process.
-            # note that we consider file changes, since we **always** generate
-            # a single opendapi file if there arent any for non dapis
-            if (
-                not (self.base_collect and self.base_collect.original)
-                and self.head_collect.merged
-            ):
-                return True, "NON_DAPI_FILE_CREATED"
-
-            # if the file changed from base, we need to process
-            if (
-                self.base_collect and self.base_collect.original
-            ) != self.head_collect.merged:
-                return True, "NON_DAPI_FILE_CHANGED_FROM_BASE"
-
-            # if the file changed from head, we need to process
-            if self.head_collect.merged != self.head_collect.original:
-                return True, "NON_DAPI_FILE_CHANGED_FROM_HEAD"
-
-            return False, "NON_DAPI_FILE_NO_CHANGE"
-
-        # we consider if the model itself still exists
-        if self.head_collect.generated:
-            # there was a meaningful change to the model.
-            # we need to process
-            if self.entity_changed_from_base:
-                return True, "MODEL_EXISTS_AND_ENTITY_CHANGED"
-
-            # there was no meaningful change to the model, but
-            # there is no dapi. we need to create one.
-            if not self.head_collect.original:
-                return True, "MODEL_EXISTS_AND_NO_FILE"
-
-            # there was no meaningful change to the model, the dapi exists,
-            # but the dapi materially differs from the model, meaning it is out of sync.
-            # note that this only applies to actual models.
-            # we need to process
-            # note that we compare against merged, since we want to respect nullability changes
-            if has_underlying_model_changed(
-                self.head_collect.merged,
-                self.head_collect.original,
-            ):
-                return True, "MODEL_EXISTS_AND_FILE_OUT_OF_SYNC"
-
-            # no meaningful change to the model and the dapi is synced.
-            # in this scenario, we just need to make sure that manual
-            # changes are sane.
-            # either the file was just added - which is the case above - or
-            # the file was manually changed, in both cases we need to process
-            if self.head_collect.original != (
-                self.base_collect and self.base_collect.original
-            ):
-                return True, "MODEL_EXISTS_AND_FILE_CHANGE"
-
-            return False, "MODEL_EXISTS_AND_NO_CHANGE"
-
-        # now we consider the file existing but the model not existing.
-        # if there were any changes to the file, we need to process
-        # either the entity was just deleted but not the file, the file is a vestige and changed,
-        # or the file was manually added
-        if has_dapi_file_materially_changed(
-            self.head_collect.original,
-            self.base_collect and self.base_collect.original,
-        ):
-            return True, "MODEL_DOESNT_EXIST_FILE_EXISTS_AND_CHANGED"
-
-        return False, "MODEL_DOESNT_EXIST_FILE_EXISTS_AND_NO_CHANGE"
-
-    @functools.cached_property
-    def should_be_processed(self) -> Tuple[bool, str]:
-        """Check if the entity should be processed"""
-        result, _ = self._should_be_processed
-        return result
-
-    @property
-    def should_be_processed_reason(self) -> str:
-        """Get the reason for processing the entity."""
-        _, reason = self._should_be_processed
-        return reason
-
-    @functools.cached_property
-    def orm_unsynced_at_base(self) -> bool:
-        """
-        Check if the ORM is unsynced at base.
-
-        Can be due to the model not yet being onboarded,
-        or if the metadata suggestions were not applied.
-        """
-        return (
-            self.entity is OpenDAPIEntity.DAPI
-            and bool(self.base_collect)
-            and has_underlying_model_changed(
-                self.base_collect.merged,
-                self.base_collect.original,
-            )
-        )
-
-    @property
-    def required_for_minimal_cicd(self) -> bool:
-        """Check if the entity should be processed for CICD"""
-        # we only process changed dapis
-        if self.entity is OpenDAPIEntity.DAPI:
-            return self.should_be_processed
-
-        # but all other entities are required for CICD
-        return bool(self.head_collect and self.head_collect.merged)
-
-    @property
-    def for_server(self) -> dict:
-        """Convert to dict."""
-        return {
-            "entity": self.entity.value,
-            "filepath": self.filepath,
-            "base_collect": self.base_collect.for_server if self.base_collect else None,
-            "head_collect": self.head_collect.for_server if self.head_collect else None,
-            "entity_changed_from_base": self.entity_changed_from_base,
-            "entity_is_new": self.entity_is_new,
-            "entity_is_deprecated": self.entity_is_deprecated,
-            "file_git_tracked": self.file_git_tracked,
-            "integration_mode": self.integration_mode,
-            "should_be_processed": self.should_be_processed,
-            "should_be_processed_reason": self.should_be_processed_reason,
-            "orm_unsynced_at_base": self.orm_unsynced_at_base,
-            "required_for_minimal_cicd": self.required_for_minimal_cicd,
-        }
-
-
 class DAPIRequests:
     """Class to handle requests to the DAPI Server."""
 
