@@ -3,55 +3,191 @@
 
 from __future__ import annotations
 
+import os
 import re
 import subprocess  # nosec: B404
 from dataclasses import asdict, dataclass
-from typing import List, Optional, Tuple
+from typing import Generator, List, Optional, Tuple, Union
 
-from opendapi.cli.common import print_encoded_breadcrumbs
-from opendapi.defs import ALL_OPENDAPI_SUFFIXES, REFS_PREFIXES, CommitType
+from opendapi.defs import REFS_PREFIXES, CommitType
 from opendapi.logging import logger
 
 
-def run_git_command(cwd: str, command_split: List[str]) -> str:
-    """Run a git command."""
+def run_git(
+    cwd: str,
+    args: list[str],
+    *,
+    decode_to_str: bool = False,
+) -> Union[str, bytes]:
+    """
+    Non-streaming git runner - returns values directly.
+
+    Args:
+        cwd: Working directory for the git command
+        args: Git command arguments (without 'git')
+        decode_to_str: If True, decode output to string and strip whitespace
+
+    Returns:
+        Command output as bytes or decoded string
+    """
+    cmd = ["git", "--no-pager", *args]
+
     try:
-        return subprocess.check_output(
-            command_split,
+        out = subprocess.run(  # nosec: B603
+            cmd,
             cwd=cwd,
-        )  # nosec
+            capture_output=True,
+            check=True,
+        ).stdout
     except subprocess.CalledProcessError as exc:
-        # KBtodo: Figure out why this is not sent to sentry but CI fails
-        print_encoded_breadcrumbs(f"git command {command_split}: {exc}")
-        raise RuntimeError(f"git command {command_split}: {exc}") from exc
+        err = exc.stderr.decode("utf-8", "replace") if exc.stderr else str(exc)
+        logger.exception("git %s failed: %s", args, err)
+        raise RuntimeError(f"git {args} failed: {err}") from exc
+
+    return out if not decode_to_str else out.decode("utf-8", "replace").strip()
+
+
+def stream_git(
+    cwd: str,
+    args: list[str],
+    *,
+    delimiter: Optional[bytes] = None,  # b"\x00" for -z, b"\n" for lines
+    decode_to_str: bool = False,  # if False, don't decode
+) -> Generator[Union[str, bytes], None, None]:
+    """
+    Streaming git runner - yields values as they become available.
+
+    Args:
+        cwd: Working directory for the git command
+        args: Git command arguments (without 'git')
+        delimiter: Split output by this delimiter (None for raw chunks)
+        decode_to_str: If True, decode output to string
+
+    Yields:
+        Command output chunks as bytes or decoded strings
+    """
+    cmd = ["git", "--no-pager", *args]
+
+    try:
+        with subprocess.Popen(  # nosec: B603
+            cmd,
+            cwd=cwd,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        ) as proc:
+            if delimiter is None:
+                # raw chunk streaming
+                for chunk in iter(lambda: proc.stdout.read(65536), b""):
+                    yield (
+                        chunk if not decode_to_str else chunk.decode("utf-8", "replace")
+                    )
+            else:
+                buf = b""
+                for chunk in iter(lambda: proc.stdout.read(65536), b""):
+                    buf += chunk
+                    *parts, buf = buf.split(delimiter)
+                    for p in parts:
+                        yield p if not decode_to_str else p.decode("utf-8", "replace")
+                if buf:
+                    yield buf if not decode_to_str else buf.decode("utf-8", "replace")
+
+            rc = proc.wait()
+            if rc != 0:
+                err = proc.stderr.read().decode("utf-8", "replace")
+                logger.exception("git %s exited %s: %s", args, rc, err.strip())
+                raise RuntimeError(f"git {args} exited {rc}: {err.strip()}")
+    except subprocess.CalledProcessError as exc:
+        err = exc.stderr.decode("utf-8", "replace") if exc.stderr else str(exc)
+        logger.exception("git %s failed: %s", args, err)
+        raise RuntimeError(f"git {args} failed: {err}") from exc
+
+
+def iter_git_files(
+    repo_root: str,  # abs path
+    *,
+    suffixes: Optional[List[str]] = None,
+    rel_prefixes: Optional[List[str]] = None,  # repo-rel
+    exclude_dirs: Optional[List[str]] = None,  # dir names (no globs)
+    include_untracked: bool = False,
+    return_absolute: bool = False,
+) -> Generator[str, None, None]:
+    """
+    Yield absolute file paths from `git ls-files`, filtered by:
+      - rel_prefixes: limit to these subtrees
+      - exclude_dirs: exclude any files under these directory names
+      - suffixes: restrict to these file suffixes (e.g., [".sql", ".ini"])
+      - include_untracked: include untracked-but-unignored files
+    Uses stream_git() with NUL-delimited output for robustness & streaming.
+    """
+    # Normalize prefixes to repo-relative POSIX
+    prefixes = rel_prefixes or ["."]
+    if not os.path.isabs(repo_root):
+        raise ValueError("repo_root must be an absolute path")
+
+    if any(os.path.isabs(p) for p in prefixes):
+        raise ValueError("rel_prefixes must be relative paths")
+
+    # Build include pathspecs (prefix × suffix)
+    if suffixes:
+        pathspecs = []
+        for sfx in suffixes:
+            for pref in prefixes:
+                if pref != ".":
+                    pathspecs += [f"{pref}/**/*{sfx}", f"{pref}/*{sfx}"]
+                else:
+                    pathspecs += [f"**/*{sfx}", f"*{sfx}"]
+    else:
+        pathspecs = prefixes
+
+    # Build exclude pathspecs (dir-name based)
+    excl_names = list(set(exclude_dirs or []))
+    exclude_specs = [f":(exclude,glob)**/{d}/**" for d in excl_names]
+
+    args = ["ls-files", "-z"]
+    untracked_args = ["--others", "--exclude-standard"]
+    specs = pathspecs + exclude_specs
+
+    seen = set()
+    # Stream NUL-delimited records, decoded to str
+    for rel_path in stream_git(
+        repo_root, [*args, "--", *specs], delimiter=b"\x00", decode_to_str=True
+    ):
+        if not rel_path or rel_path in seen:  # defensive (trailing NUL)
+            continue
+        seen.add(rel_path)
+        yield os.path.join(repo_root, rel_path) if return_absolute else rel_path
+
+    if include_untracked:
+        for rel_path in stream_git(
+            repo_root,
+            [*args, *untracked_args, "--", *specs],
+            delimiter=b"\x00",
+            decode_to_str=True,
+        ):
+            if not rel_path or rel_path in seen:  # defensive (trailing NUL)
+                continue
+            seen.add(rel_path)
+            yield os.path.join(repo_root, rel_path) if return_absolute else rel_path
 
 
 def get_commit_timestamp_str(cwd: str, commit_sha: str) -> str:
     """Get the commit timestamp string."""
-    return (
-        run_git_command(
-            cwd,
-            [
-                "git",
-                "show",
-                "--format=%cd",
-                "--no-patch",
-                "--date=iso-strict",
-                commit_sha,
-            ],
-        )
-        .decode("utf-8")
-        .strip()
+    return run_git(
+        cwd,
+        [
+            "show",
+            "--format=%cd",
+            "--no-patch",
+            "--date=iso-strict",
+            commit_sha,
+        ],
+        decode_to_str=True,
     )
 
 
 def get_merge_base(cwd: str, current_ref: str, base_ref: str) -> str:
     """Get the merge base of two refs."""
-    merge_base = (
-        run_git_command(cwd, ["git", "merge-base", current_ref, base_ref])
-        .decode("utf-8")
-        .strip()
-    )
+    merge_base = run_git(cwd, ["merge-base", current_ref, base_ref], decode_to_str=True)
     logger.info("Merge base of %s and %s is %s", current_ref, base_ref, merge_base)
     return merge_base
 
@@ -61,13 +197,10 @@ def get_upstream_commit_sha(cwd: str, ref: str, steps: int) -> str:
     if steps < 0:
         raise ValueError("Steps must be non-negative")
 
-    upstream_sha = (
-        run_git_command(
-            cwd,
-            ["git", "rev-parse", f"{ref}~{steps}"],
-        )
-        .decode("utf-8")
-        .strip()
+    upstream_sha = run_git(
+        cwd,
+        ["rev-parse", f"{ref}~{steps}"],
+        decode_to_str=True,
     )
     logger.info("Upstream commit SHA of %s~%s is %s", ref, steps, upstream_sha)
     return upstream_sha
@@ -76,16 +209,12 @@ def get_upstream_commit_sha(cwd: str, ref: str, steps: int) -> str:
 def get_checked_out_branch_or_commit(cwd: str) -> str:
     """Get the checked out branch or commit."""
     # if a branch is checked out, returns the branch name, if a commit is, it returns HEAD
-    branch_name_or_head = (
-        run_git_command(cwd, ["git", "rev-parse", "--abbrev-ref", "HEAD"])
-        .decode("utf-8")
-        .strip()
+    branch_name_or_head = run_git(
+        cwd, ["rev-parse", "--abbrev-ref", "HEAD"], decode_to_str=True
     )
     # if the branch is detached, it returns the commit hash
     if branch_name_or_head == "HEAD":
-        return (
-            run_git_command(cwd, ["git", "rev-parse", "HEAD"]).decode("utf-8").strip()
-        )
+        return run_git(cwd, ["rev-parse", "HEAD"], decode_to_str=True)
     return branch_name_or_head
 
 
@@ -93,7 +222,7 @@ def _get_current_stash_names_with_index(cwd: str) -> List[Tuple[int, str]]:
     return [
         (i, stash.split(": ")[-1])
         for i, stash in enumerate(
-            run_git_command(cwd, ["git", "stash", "list"]).decode("utf-8").split("\n")
+            run_git(cwd, ["stash", "list"], decode_to_str=True).split("\n")
         )
     ]
 
@@ -110,12 +239,8 @@ def add_named_stash(cwd: str, stash_name: str) -> bool:
     current_stashes = [stash for _, stash in _get_current_stash_names_with_index(cwd)]
     if stash_name in current_stashes:
         raise ValueError(f"Stash {stash_name} already exists")
-    result = (
-        run_git_command(
-            cwd, ["git", "stash", "save", "--include-untracked", stash_name]
-        )
-        .decode("utf-8")
-        .strip()
+    result = run_git(
+        cwd, ["stash", "save", "--include-untracked", stash_name], decode_to_str=True
     )
     return result != "No local changes to save"
 
@@ -129,82 +254,27 @@ def pop_named_stash(cwd: str, stash_name: str) -> None:
     )
     if stash_index is None:
         raise ValueError(f"Stash {stash_name} not found")
-    run_git_command(cwd, ["git", "stash", "pop", f"stash@{{{stash_index}}}"])
+    run_git(cwd, ["stash", "pop", f"stash@{{{stash_index}}}"])
 
 
-def get_changed_opendapi_filenames(cwd: str) -> List[str]:
-    """Get the list of changed opendapi files."""
-    files_patterns = ["*" + suffix for suffix in ALL_OPENDAPI_SUFFIXES]
-    all_files_command = [
-        "git",
-        "status",
-        "--porcelain",
-        *files_patterns,
-    ]
-    result = run_git_command(cwd, all_files_command)
-    if not result:
-        return []
-    result = result.decode("utf-8").replace("'", "")
-    return [r.split(" ", 2)[-1] for r in result.split("\n") if r]
-
-
-def add_untracked_opendapi_files(
-    cwd: str, files_patterns: Optional[List[str]] = None
-) -> int:
-    """Add opendapi relevant untracked files to git and return number of files added."""
-    files_patterns = files_patterns or [
-        "*" + suffix for suffix in ALL_OPENDAPI_SUFFIXES
-    ]
-    all_files_command = [
-        "git",
-        "add",
-        "--dry-run",
-        "--ignore-missing",
-        *files_patterns,
-    ]
-    result = run_git_command(cwd, all_files_command)
-    if result:
-        result = result.decode("utf-8").replace("'", "")
-        all_files = [r.split(" ", 2)[-1] for r in result.split("\n") if r]
-        run_git_command(cwd, ["git", "add", *all_files])
-        return len(all_files)
-    return 0  # pragma: no cover
-
-
-def get_git_diff_filenames(
-    root_dir: str,
-    base_ref: str,
-    current_ref: Optional[str] = None,
-    cached: bool = False,
-) -> List[str]:
-    """Get the list of files changed between current and main branch"""
-    commands = [
-        "git",
-        "diff",
-        *(["--cached"] if cached else []),
-        *["--name-only", base_ref],
-        *([current_ref] if current_ref else []),
-    ]
-    files = run_git_command(root_dir, commands)
-    return [filename for filename in files.decode("utf-8").split("\n") if filename]
-
-
-def get_uncommitted_changes(cwd: str) -> bytes:
+def get_uncommitted_changes(cwd: str) -> str:
     """Get the uncommitted changes."""
-    return run_git_command(cwd, ["git", "diff", "--name-only"])
+    return run_git(cwd, ["diff", "--name-only"], decode_to_str=True)
 
 
-def get_untracked_changes(cwd: str) -> bytes:
+def get_untracked_changes(cwd: str) -> str:
     """Get the untracked changes."""
-    return run_git_command(cwd, ["git", "ls-files", "--others", "--exclude-standard"])
+    return run_git(
+        cwd, ["ls-files", "--others", "--exclude-standard"], decode_to_str=True
+    )
 
 
-def check_if_uncomitted_or_untracked_changes_exist(
+def check_if_uncommitted_or_untracked_changes_exist(
     cwd: str, log_exception: bool = True
 ) -> bool:
     """Check if uncommitted or untracked changes exist."""
-    uncommitted_changes = get_uncommitted_changes(cwd).decode("utf-8")
-    untracked_changes = get_untracked_changes(cwd).decode("utf-8")
+    uncommitted_changes = get_uncommitted_changes(cwd)
+    untracked_changes = get_untracked_changes(cwd)
     if (uncommitted_changes or untracked_changes) and log_exception:
         logger.exception(
             "Uncommitted: %s, Untracked: %s", uncommitted_changes, untracked_changes
@@ -228,15 +298,13 @@ class GitCommitStasher:
         self.stash_created = False
         self.pre_checkout_sha = None
         # reduce noise about detached head
-        run_git_command(
-            self.cwd, ["git", "config", "--global", "advice.detachedHead", "false"]
-        )
+        run_git(self.cwd, ["config", "--global", "advice.detachedHead", "false"])
 
     def _reset(self):
         """
         Reset the state of the stasher.
         """
-        run_git_command(self.cwd, ["git", "checkout", self.pre_checkout_sha])
+        run_git(self.cwd, ["checkout", self.pre_checkout_sha])
 
         if self.stash_created:
             pop_named_stash(self.cwd, self.stash_name)
@@ -250,12 +318,12 @@ class GitCommitStasher:
             raise ValueError("Already stashed")
         self.stash_created = add_named_stash(self.cwd, self.stash_name)
         # sanity check
-        if check_if_uncomitted_or_untracked_changes_exist(self.cwd):
+        if check_if_uncommitted_or_untracked_changes_exist(self.cwd):
             self._reset()
             raise RuntimeError("You have uncommitted or untracked changes after stash")
         self.currently_stashed = True
         self.pre_checkout_sha = get_checked_out_branch_or_commit(self.cwd)
-        run_git_command(self.cwd, ["git", "checkout", self.commit_sha])
+        run_git(self.cwd, ["checkout", self.commit_sha])
         return self
 
     def __exit__(self, exc_type, exc_value, traceback) -> None:
@@ -263,7 +331,7 @@ class GitCommitStasher:
             raise ValueError("Not stashed")
 
         try:
-            if check_if_uncomitted_or_untracked_changes_exist(self.cwd):
+            if check_if_uncommitted_or_untracked_changes_exist(self.cwd):
                 raise RuntimeError("File changes were detected while stashed.")
 
         finally:
