@@ -1,6 +1,5 @@
 """Common utilities for the OpenDAPI CLI."""
 
-import base64
 import functools
 import json
 import os
@@ -259,16 +258,6 @@ def pretty_print_errors(errors: List[Exception]):
             print_cli_output(err)
 
 
-ENCODED_BREADCRUMB_PREFIX = "OPENDAPI_BREADCRUMB::"
-
-
-def print_encoded_breadcrumbs(message: str):
-    """Prints the error message encoded in a way for the server"""
-    base64_bytes = base64.b64encode(message.encode("utf-8"))
-    base64_message = f"{ENCODED_BREADCRUMB_PREFIX}{base64_bytes.decode('utf-8')}"
-    print_cli_output(base64_message)
-
-
 def highlight_message(message: str):
     """Highlights the message"""
     return f"\n{'>' * 30}\n\n{message}\n\n{'>' * 30}\n"
