@@ -22,12 +22,17 @@ from opendapi.cli.common import (
 )
 from opendapi.cli.options import (
     BASE_COMMIT_SHA_PARAM_NAME_WITH_OPTION,
+    OPENDAPI_CONFIG_PARAM_NAME_WITH_OPTION,
     construct_dapi_server_config,
 )
 from opendapi.cli.utils import (
+    cleanup_opendapi_cache,
     cleanup_tmp_state,
     collected_files_tmp_dump,
     collected_files_tmp_load,
+    missing_dapi_file_exists,
+    write_cicd_initialized_file,
+    write_missing_dapis_to_cache,
 )
 from opendapi.defs import (
     DAPI_CLIENT_REQUIRED_MINIMAL_SCHEMA,
@@ -56,7 +61,9 @@ def repo_runner_cli(
     etc.
     """
     # first lets make sure that the opendapi config is available
-    _ = get_opendapi_config_from_root(
+    _ = kwargs.get(
+        OPENDAPI_CONFIG_PARAM_NAME_WITH_OPTION.name
+    ) or get_opendapi_config_from_root(
         local_spec_path=kwargs.get("local_spec_path"),
         validate_config=True,
     )
@@ -130,7 +137,340 @@ def repo_runner_run_cli(
             ctx.invoke(command, **command_kwargs)
 
 
-##########
+########## CICD general ##########
+
+
+def server_sync_minimal_schemas() -> Schemas:
+    """
+    Returns the minimal schemas for server-driven CICD
+    """
+    # NOTE: Currently only DAPI schemas need minimal schemas
+    #       all other schemas produced by the validators are already minimal
+    return Schemas.create(
+        dapi=DAPI_CLIENT_REQUIRED_MINIMAL_SCHEMA,
+    )
+
+
+def get_maximal_schemas() -> Schemas:
+    """
+    Returns the maximal schemas for server-driven CICD, empty since if there arent
+    any there is nothing to prune
+    """
+    return Schemas.create()
+
+
+##### 1) init the cicd #####
+
+
+def cicd_init(
+    opendapi_config: OpenDAPIConfig,
+    change_trigger_event: ChangeTriggerEvent,
+    kwargs: dict,
+    *,
+    should_write_cicd_initialized_file: bool = True,
+) -> Tuple[str, dict]:
+    """
+    Initialize the DAPI server-driven CICD
+    """
+    print_cli_output(
+        "Initializing DAPI server-driven CICD...",
+    )
+    dapi_server_config = construct_dapi_server_config(kwargs)
+    dapi_requests = DAPIRequests(
+        dapi_server_config=dapi_server_config,
+        trigger_event=change_trigger_event,
+    )
+    cicd_location_id, s3_upload_data = dapi_requests.cicd_get_cicd_location_id()
+    if should_write_cicd_initialized_file:
+        write_cicd_initialized_file(
+            {
+                "cicd_location_id": cicd_location_id,
+                "base_commit_sha": change_trigger_event.before_change_sha,
+                "head_commit_sha": change_trigger_event.after_change_sha,
+                "head_commit_sha_timestamp": change_trigger_event.after_change_sha_timestamp,
+                "opendapi_config": opendapi_config.get_serialized(),
+            }
+        )
+    print_cli_output(
+        f"Finished initializing DAPI server-driven CICD with CICD Location ID: {cicd_location_id}",
+        color="green",
+    )
+    return cicd_location_id, s3_upload_data
+
+
+##### 2) collect files #####
+
+
+def collect_collected_files(  # pylint: disable=too-many-arguments
+    opendapi_config: OpenDAPIConfig,
+    change_trigger_event: ChangeTriggerEvent,
+    commit_type: CommitType,
+    runtime_skip_generation: bool,
+    dbt_skip_generation: bool,
+    minimal_schemas: Schemas,
+    runtime: str,
+    commit_already_checked_out: bool,
+    kwargs: dict,
+):
+    """
+    Collects the DAPI files for the given runtime at the specified commit
+    """
+    if change_trigger_event.where != "local" and not missing_dapi_file_exists():
+        print_cli_output(
+            "Fetching possible missing DAPI files from server...",
+            color="yellow",
+        )
+        dapi_server_config = construct_dapi_server_config(kwargs)
+        dapi_requests = DAPIRequests(
+            dapi_server_config=dapi_server_config,
+            trigger_event=change_trigger_event,
+        )
+        missing_dapis_by_filepath = dapi_requests.cicd_get_missing_dapis()
+        write_missing_dapis_to_cache(missing_dapis_by_filepath)
+        print_cli_output(
+            "Successfully fetched possible missing DAPI files from server",
+            color="green",
+        )
+
+    commit_sha = (
+        None
+        if commit_type is CommitType.CURRENT
+        else change_trigger_event.commit_type_to_sha(commit_type)
+    )
+    state_str = (
+        f"{commit_type.value} commit: {commit_sha}" if commit_sha else "current state"
+    )
+    print_cli_output(
+        (
+            "Accumulating DAPI files for your integrations per "
+            f"`opendapi.config.yaml` configuration at {state_str}"
+            f" for runtime {runtime}"
+        ),
+        color="green",
+    )
+
+    opendapi_config.assert_runtime_exists(runtime)
+
+    metrics_tags = {"org_name": opendapi_config.org_name_snakecase}
+    with Timer(dist_key=LogDistKey.COLLECT_FILES, tags=metrics_tags):
+
+        print_cli_output(
+            f"Tackling {state_str}...",
+            color="yellow",
+        )
+        collected_files, errors = collect_and_validate_cached(
+            opendapi_config=opendapi_config,
+            minimal_schemas=minimal_schemas,
+            runtime=runtime,
+            change_trigger_event=change_trigger_event,
+            commit_type=commit_type,
+            commit_already_checked_out=commit_already_checked_out,
+            # integration specific flags
+            runtime_skip_generation=runtime_skip_generation,
+            dbt_skip_generation=dbt_skip_generation,
+        )
+        if errors:
+            pretty_print_errors(errors)
+            # fails with exit code 1 - meaning it blocks merging - but as a ClickException
+            # it does not go to sentry, which is appropriate, as this is not an error condition
+            raise click.ClickException("Encountered one or more validation errors")
+
+        return collected_files
+
+
+##### 3) locally persist files #####
+
+
+def locally_persist_collected_files(
+    collected_files: Dict[OpenDAPIEntity, Dict[str, CollectedFile]],
+    opendapi_config: OpenDAPIConfig,
+    commit_type: CommitType,
+    runtime: str,
+):
+    """
+    Persists the collected files to the filesystem, to be loaded later
+    """
+    metrics_tags = {"org_name": opendapi_config.org_name_snakecase}
+    with Timer(dist_key=LogDistKey.PERSIST_COLLECTED_FILES, tags=metrics_tags):
+        print_cli_output(
+            "Persisting to filesystem...",
+            color="yellow",
+        )
+        collected_files_tmp_dump(commit_type, collected_files, runtime)
+        print_cli_output(
+            f"Successfully persisted DAPI files for your integrations for runtime {runtime}",
+            color="green",
+        )
+
+
+##### 4) load locally persisted files #####
+
+
+def load_locally_persisted_collected_files(
+    opendapi_config: OpenDAPIConfig,
+    commit_type: CommitType,
+    runtime: str,
+):
+    """
+    Loads the collected files from the filesystem
+    """
+    opendapi_config.assert_runtime_exists(runtime)
+
+    print_cli_output(
+        (
+            f"Loading persisted DAPI files for your integrations for runtime {runtime} "
+            f"at commit type {commit_type.value}..."
+        ),
+        color="yellow",
+    )
+
+    metrics_tags = {"org_name": opendapi_config.org_name_snakecase}
+    with Timer(dist_key=LogDistKey.LOAD_COLLECTED_FILES, tags=metrics_tags):
+        collected_files = collected_files_tmp_load(commit_type, runtime)
+
+    print_cli_output(
+        (
+            f"Successfully loaded persisted DAPI files for your integrations for runtime {runtime} "
+            f"at commit type {commit_type.value}"
+        ),
+        color="green",
+    )
+    return collected_files
+
+
+##### 5) get s3 upload data #####
+
+
+def cicd_get_s3_upload_data(
+    cicd_location_id: str,
+    change_trigger_event: ChangeTriggerEvent,
+    kwargs: dict,
+) -> dict:
+    """
+    Get the s3 upload data for the given cicd location id
+    """
+    dapi_server_config = construct_dapi_server_config(kwargs)
+    dapi_requests = DAPIRequests(
+        dapi_server_config=dapi_server_config,
+        trigger_event=change_trigger_event,
+    )
+    return dapi_requests.cicd_get_s3_upload_data(
+        cicd_location_id=cicd_location_id,
+    )
+
+
+##### 6) persist files to server #####
+
+
+def cicd_persist_files(  # pylint: disable=too-many-arguments, too-many-locals
+    base_collected_files: Dict[OpenDAPIEntity, Dict[str, CollectedFile]],
+    head_collected_files: Dict[OpenDAPIEntity, Dict[str, CollectedFile]],
+    change_trigger_event: ChangeTriggerEvent,
+    opendapi_config: OpenDAPIConfig,
+    s3_upload_data: dict,
+    runtime: str,
+    kwargs: dict,
+):
+    """
+    Posts the collected files to the DAPI  server for server-driven CICD
+    """
+    metrics_tags = {"org_name": opendapi_config.org_name_snakecase}
+    with Timer(dist_key=LogDistKey.SERVER_SYNC_TO_SERVER, tags=metrics_tags):
+        dapi_server_config = construct_dapi_server_config(kwargs)
+        dapi_requests = DAPIRequests(
+            dapi_server_config=dapi_server_config,
+            trigger_event=change_trigger_event,
+        )
+
+        print_cli_output(
+            f"Syncing with DAPI Server for runtime {runtime}...",
+            color="yellow",
+        )
+
+        total_filepaths = {
+            fp
+            for entity_collected in (base_collected_files, head_collected_files)
+            for filepaths in entity_collected.values()
+            for fp in filepaths
+        }
+
+        with click.progressbar(length=len(total_filepaths)) as progressbar:
+
+            def _notify_progress(progress: int):  # pragma: no cover
+                progressbar.update(progress)
+                print_cli_output(
+                    (
+                        f"\nFinished {round(progressbar.pct * 100)}% with"
+                        f"{progressbar.format_eta()} remaining"
+                    ),
+                    color="green",
+                    bold=True,
+                )
+
+            dapi_requests.cicd_persist_files(
+                s3_upload_data=s3_upload_data,
+                base_collected_files=base_collected_files,
+                head_collected_files=head_collected_files,
+                runtime=runtime,
+                notify_function=_notify_progress,
+            )
+
+        print_cli_output(
+            (
+                "Successfully synced DAPI files for your integrations to DAPI Server "
+                f"for runtime {runtime}"
+            ),
+            color="green",
+        )
+
+
+##### 7) start server driven CICD #####
+
+
+def cicd_start(
+    call_cicd_start: Callable[[DAPIRequests, dict], None],
+    cicd_location_id: str,
+    opendapi_config: OpenDAPIConfig,
+    change_trigger_event: ChangeTriggerEvent,
+    cicd_integration: CICDIntegration,
+    runner_run_info: dict,
+    kwargs: dict,
+):
+    """
+    Start the DAPI server-driven CICD
+    """
+    dapi_server_config = construct_dapi_server_config(kwargs)
+    dapi_requests = DAPIRequests(
+        dapi_server_config=dapi_server_config,
+        trigger_event=change_trigger_event,
+    )
+    metadata_file = {
+        "runtimes": opendapi_config.runtime_names,
+        "run_info": {
+            "version": f"opendapi-{version('opendapi')}",
+            "integration_mode": dapi_server_config.woven_integration_mode,
+            "repo_being_configured": dapi_server_config.repo_being_configured,
+            "integration": cicd_integration.value,
+            "register_on_merge_to_mainline": (
+                dapi_server_config.register_on_merge_to_mainline
+            ),
+            "mainline_branch_name": dapi_server_config.mainline_branch_name,
+            **runner_run_info,
+        },
+        "opendapi_config": opendapi_config.config,
+        "change_trigger_event": change_trigger_event.as_dict,
+        "cicd_location_id": cicd_location_id,
+    }
+    call_cicd_start(dapi_requests, metadata_file)
+    print_cli_output(
+        "Successfully started DAPI server-driven CICD",
+        color="green",
+    )
+    cleanup_tmp_state(opendapi_config)
+    cleanup_opendapi_cache()
+
+
+##### LOCAL HELPERS #####
 
 
 def write_locally(
@@ -218,285 +558,3 @@ def reconcile_collected_files_across_runtimes(
         color="green",
     )
     return reconciled_collected_files
-
-
-def server_sync_minimal_schemas() -> Schemas:
-    """
-    Returns the minimal schemas for server-driven CICD
-    """
-    # NOTE: Currently only DAPI schemas need minimal schemas
-    #       all other schemas produced by the validators are already minimal
-    return Schemas.create(
-        dapi=DAPI_CLIENT_REQUIRED_MINIMAL_SCHEMA,
-    )
-
-
-def get_maximal_schemas() -> Schemas:
-    """
-    Returns the maximal schemas for server-driven CICD
-    """
-    return Schemas.create()
-
-
-def cicd_get_s3_upload_data(
-    woven_cicd_id: str,
-    cicd_integration: CICDIntegration,
-    change_trigger_event: ChangeTriggerEvent,
-    kwargs: dict,
-) -> dict:
-    """
-    Get the s3 upload data for the given woven cicd id and integration
-    """
-    dapi_server_config = construct_dapi_server_config(kwargs)
-    dapi_requests = DAPIRequests(
-        dapi_server_config=dapi_server_config,
-        trigger_event=change_trigger_event,
-    )
-    return dapi_requests.cicd_get_s3_upload_data(
-        woven_cicd_id=woven_cicd_id,
-        integration=cicd_integration,
-    )
-
-
-def cicd_init(
-    call_cicd_init: Callable[[DAPIRequests], Tuple[str, dict]],
-    change_trigger_event: ChangeTriggerEvent,
-    kwargs: dict,
-) -> Tuple[str, dict]:
-    """
-    Initialize the DAPI server-driven CICD
-    """
-    print_cli_output(
-        "Initializing DAPI server-driven CICD...",
-    )
-    dapi_server_config = construct_dapi_server_config(kwargs)
-    dapi_requests = DAPIRequests(
-        dapi_server_config=dapi_server_config,
-        trigger_event=change_trigger_event,
-    )
-    woven_cicd_id, s3_upload_data = call_cicd_init(dapi_requests)
-    print_cli_output(
-        f"Finished initializing DAPI server-driven CICD with Woven CICD ID: {woven_cicd_id}",
-        color="green",
-    )
-    return woven_cicd_id, s3_upload_data
-
-
-def cicd_start(
-    woven_cicd_id: str,
-    opendapi_config: OpenDAPIConfig,
-    change_trigger_event: ChangeTriggerEvent,
-    cicd_integration: CICDIntegration,
-    runner_run_info: dict,
-    kwargs: dict,
-):
-    """
-    Start the DAPI server-driven CICD
-    """
-    dapi_server_config = construct_dapi_server_config(kwargs)
-    dapi_requests = DAPIRequests(
-        dapi_server_config=dapi_server_config,
-        trigger_event=change_trigger_event,
-    )
-    metadata_file = {
-        "runtimes": opendapi_config.runtime_names,
-        "run_info": {
-            "version": f"opendapi-{version('opendapi')}",
-            "integration_mode": dapi_server_config.woven_integration_mode,
-            "repo_being_configured": dapi_server_config.repo_being_configured,
-            "integration": cicd_integration.value,
-            "register_on_merge_to_mainline": (
-                dapi_server_config.register_on_merge_to_mainline
-            ),
-            "mainline_branch_name": dapi_server_config.mainline_branch_name,
-            **runner_run_info,
-        },
-        "opendapi_config": opendapi_config.config,
-        "change_trigger_event": change_trigger_event.as_dict,
-        "woven_cicd_id": woven_cicd_id,
-    }
-    dapi_requests.cicd_start(
-        integration=cicd_integration,
-        metadata_file=metadata_file,
-        woven_cicd_id=woven_cicd_id,
-    )
-    print_cli_output(
-        "Successfully initiated DAPI server-driven CICD",
-        color="green",
-    )
-    cleanup_tmp_state(opendapi_config)
-
-
-def cicd_persist_files(  # pylint: disable=too-many-arguments, too-many-locals
-    base_collected_files: Dict[OpenDAPIEntity, Dict[str, CollectedFile]],
-    head_collected_files: Dict[OpenDAPIEntity, Dict[str, CollectedFile]],
-    change_trigger_event: ChangeTriggerEvent,
-    opendapi_config: OpenDAPIConfig,
-    s3_upload_data: dict,
-    runtime: str,
-    kwargs: dict,
-):
-    """
-    Posts the collected files to the DAPI server for server-driven CICD
-    """
-    metrics_tags = {"org_name": opendapi_config.org_name_snakecase}
-    with Timer(dist_key=LogDistKey.SERVER_SYNC_TO_SERVER, tags=metrics_tags):
-        dapi_server_config = construct_dapi_server_config(kwargs)
-        dapi_requests = DAPIRequests(
-            dapi_server_config=dapi_server_config,
-            trigger_event=change_trigger_event,
-        )
-
-        print_cli_output(
-            f"Syncing with DAPI Server for runtime {runtime}...",
-            color="yellow",
-        )
-
-        total_filepaths = {
-            fp
-            for entity_collected in (base_collected_files, head_collected_files)
-            for filepaths in entity_collected.values()
-            for fp in filepaths
-        }
-
-        with click.progressbar(length=len(total_filepaths)) as progressbar:
-
-            def _notify_progress(progress: int):  # pragma: no cover
-                progressbar.update(progress)
-                print_cli_output(
-                    (
-                        f"\nFinished {round(progressbar.pct * 100)}% with"
-                        f"{progressbar.format_eta()} remaining"
-                    ),
-                    color="green",
-                    bold=True,
-                )
-
-            dapi_requests.cicd_persist_files(
-                s3_upload_data=s3_upload_data,
-                base_collected_files=base_collected_files,
-                head_collected_files=head_collected_files,
-                runtime=runtime,
-                notify_function=_notify_progress,
-            )
-
-        print_cli_output(
-            (
-                "Successfully synced DAPI files for your integrations to DAPI Server "
-                f"for runtime {runtime}"
-            ),
-            color="green",
-        )
-
-
-def collect_collected_files(  # pylint: disable=too-many-arguments
-    opendapi_config: OpenDAPIConfig,
-    change_trigger_event: ChangeTriggerEvent,
-    commit_type: CommitType,
-    runtime_skip_generation: bool,
-    dbt_skip_generation: bool,
-    minimal_schemas: Schemas,
-    runtime: str,
-    commit_already_checked_out: bool,
-):
-    """
-    Collects the DAPI files for the given runtime at the specified commit
-    """
-    commit_sha = (
-        None
-        if commit_type is CommitType.CURRENT
-        else change_trigger_event.commit_type_to_sha(commit_type)
-    )
-    state_str = (
-        f"{commit_type.value} commit: {commit_sha}" if commit_sha else "current state"
-    )
-    print_cli_output(
-        (
-            "Accumulating DAPI files for your integrations per "
-            f"`opendapi.config.yaml` configuration at {state_str}"
-            f" for runtime {runtime}"
-        ),
-        color="green",
-    )
-
-    opendapi_config.assert_runtime_exists(runtime)
-
-    metrics_tags = {"org_name": opendapi_config.org_name_snakecase}
-    with Timer(dist_key=LogDistKey.COLLECT_FILES, tags=metrics_tags):
-
-        print_cli_output(
-            f"Tackling {state_str}...",
-            color="yellow",
-        )
-        collected_files, errors = collect_and_validate_cached(
-            opendapi_config=opendapi_config,
-            minimal_schemas=minimal_schemas,
-            runtime=runtime,
-            change_trigger_event=change_trigger_event,
-            commit_type=commit_type,
-            commit_already_checked_out=commit_already_checked_out,
-            # integration specific flags
-            runtime_skip_generation=runtime_skip_generation,
-            dbt_skip_generation=dbt_skip_generation,
-        )
-        if errors:
-            pretty_print_errors(errors)
-            # fails with exit code 1 - meaning it blocks merging - but as a ClickException
-            # it does not go to sentry, which is appropriate, as this is not an error condition
-            raise click.ClickException("Encountered one or more validation errors")
-
-        return collected_files
-
-
-def persist_collected_files(
-    collected_files: Dict[OpenDAPIEntity, Dict[str, CollectedFile]],
-    opendapi_config: OpenDAPIConfig,
-    commit_type: CommitType,
-    runtime: str,
-):
-    """
-    Persists the collected files to the filesystem, to be loaded later
-    """
-    metrics_tags = {"org_name": opendapi_config.org_name_snakecase}
-    with Timer(dist_key=LogDistKey.PERSIST_COLLECTED_FILES, tags=metrics_tags):
-        print_cli_output(
-            "Persisting to filesystem...",
-            color="yellow",
-        )
-        collected_files_tmp_dump(commit_type, collected_files, runtime)
-        print_cli_output(
-            f"Successfully persisted DAPI files for your integrations for runtime {runtime}",
-            color="green",
-        )
-
-
-def load_collected_files(
-    opendapi_config: OpenDAPIConfig,
-    commit_type: CommitType,
-    runtime: str,
-):
-    """
-    Loads the collected files from the filesystem
-    """
-    opendapi_config.assert_runtime_exists(runtime)
-
-    print_cli_output(
-        (
-            f"Loading persisted DAPI files for your integrations for runtime {runtime} "
-            f"at commit type {commit_type.value}..."
-        ),
-        color="yellow",
-    )
-
-    metrics_tags = {"org_name": opendapi_config.org_name_snakecase}
-    with Timer(dist_key=LogDistKey.LOAD_COLLECTED_FILES, tags=metrics_tags):
-        collected_files = collected_files_tmp_load(commit_type, runtime)
-
-    print_cli_output(
-        (
-            f"Successfully loaded persisted DAPI files for your integrations for runtime {runtime} "
-            f"at commit type {commit_type.value}"
-        ),
-        color="green",
-    )
-    return collected_files
