@@ -4,6 +4,7 @@ Utility functions for the OpenDAPI CLI
 
 import json
 import os
+import tempfile
 from typing import Dict
 
 from opendapi.cli.common import OpenDAPIConfig
@@ -97,3 +98,64 @@ def cleanup_tmp_state(opendapi_config: OpenDAPIConfig) -> None:
     # if the dirs are not empty
     if os.path.exists(_PERSITED_COLLECTED_FILES_DIR):
         os.removedirs(_PERSITED_COLLECTED_FILES_DIR)
+
+
+def _get_cache_dir() -> str:
+    """Get the cache directory"""
+    cache_dir = os.path.join(tempfile.gettempdir(), ".cache")
+    return cache_dir
+
+
+def _get_opendapi_cache_dir() -> str:
+    """Get the opendapi cache directory"""
+    cache_dir = os.path.join(_get_cache_dir(), "opendapi")
+    return cache_dir
+
+
+def _get_opendapi_cache_filepath() -> str:
+    """Get the opendapi cache filepath"""
+    return os.path.join(_get_opendapi_cache_dir(), "missing_dapis.yaml")
+
+
+def write_missing_dapis_to_cache(missing_dapis_by_filepath: dict) -> None:
+    """
+    Write the missing DAPI files to the cache
+
+    NOTE: for flexibility we do not have the root dir as part of the filepath -
+          callers that require it should prefix it themselves
+    """
+    os.makedirs(_get_opendapi_cache_dir(), exist_ok=True)
+    with open(_get_opendapi_cache_filepath(), "w", encoding="utf-8") as f:
+        json.dump(missing_dapis_by_filepath, f)
+
+
+def load_missing_dapis_from_cache() -> dict:
+    """Load the missing DAPI files from the cache"""
+    try:
+        with open(_get_opendapi_cache_filepath(), "r", encoding="utf-8") as f:
+            return json.load(f)
+    except FileNotFoundError:
+        return {}
+
+
+def cleanup_opendapi_cache() -> None:
+    """Cleanup the opendapi cache"""
+    try:
+        os.remove(_get_opendapi_cache_filepath())
+    except FileNotFoundError:
+        pass
+
+    opendapi_cache_dir = _get_opendapi_cache_dir()
+    if os.path.exists(opendapi_cache_dir) and not os.listdir(
+        opendapi_cache_dir
+    ):  # pragma: no cover
+        os.removedirs(opendapi_cache_dir)
+
+    cache_dir = _get_cache_dir()
+    if os.path.exists(cache_dir) and not os.listdir(cache_dir):  # pragma: no cover
+        os.removedirs(cache_dir)
+
+
+def missing_dapi_file_exists() -> bool:
+    """Check if the missing DAPI file exists"""
+    return os.path.exists(_get_opendapi_cache_filepath())
