@@ -8,9 +8,7 @@ from typing import Dict
 class FeatureFlag(Enum):
     """Feature flags for the OpenDAPI client."""
 
-    DBT_WRITEBACK_ENABLED = "dbt_writeback_enabled"
-    FEATURE_VALIDATION_ENABLED = "feature_validation_enabled"
-    PERFORM_COMPLETE_SERVER_SIDE_CICD = "perform_complete_server_side_cicd"
+    USE_NEXT_OPENDAPI_ORG_PROXY = "use_next_opendapi_org_proxy"
 
     @property
     def to_env_var(self):
