@@ -107,23 +107,30 @@ class Timer:
             if isinstance(self.dist_key, LogDistKey)
             else self.dist_key
         )
-        sentry_sdk.metrics.distribution(
-            key=f"opendapi.{key_name}",
-            value=_elapsed * 1000,
-            unit="milliseconds",
-            tags=self.tags,
+        logger.info(
+            "Timer %s took %s milliseconds",
+            key_name,
+            _elapsed * 1000,
+            extra={
+                "key": key_name,
+                "elapsed": _elapsed * 1000,
+                "tags": self.tags,
+            },
         )
 
-        return False
-
 
 def increment_counter(key: LogCounterKey, value: int = 1, tags: dict = None):
     """Increment a counter metric in sentry."""
     key_name = key.value if isinstance(key, LogCounterKey) else key
-    sentry_sdk.metrics.incr(
-        key=f"opendapi.{key_name}",
-        value=value,
-        tags=tags,
+    logger.info(
+        "Counter %s incremented by %s",
+        key_name,
+        value,
+        extra={
+            "key": key_name,
+            "value": value,
+            "tags": tags,
+        },
     )
 
 
@@ -138,12 +145,6 @@ def sentry_init(
         denylist=WOVEN_DENY_LIST,
         recursive=True,
     )
-    sentry_config["_experiments"] = {
-        # Turns on the metrics module
-        "enable_metrics": True,
-        # Enables sending of code locations for metrics
-        "metric_code_locations": True,
-    }
     sentry_sdk.init(**sentry_config)
 
     # Set sentry tags
