@@ -121,8 +121,11 @@ class ConfigParam(Enum):
     PROJECT_PATH = "project_path"
     INCLUDE_ALL = "include_all"
     DIALECT = "dialect"
+    INCLUDE_PROJECTS = "include_projects"
+    INCLUDE_MODELS = "include_models"
     OVERRIDES = "overrides"
     PLAYBOOKS = "playbooks"
+    # KBTODO deprecate:model_allowlist: as part of playbooks revamp
     MODEL_ALLOWLIST = "model_allowlist"
     ARTIFACT_PATH = "artifact_path"
 
@@ -148,6 +151,7 @@ class PlaybookConfig(BaseConfig):
     identifier_prefix: Optional[str] = None
     name_transform: Optional[NameTransform] = None
     team_urn: Optional[str] = None
+    # KBTODO deprecate:model_allowlist: as part of playbooks revamp
     model_allowlist: Optional[List[str]] = field(default_factory=list)
 
     def __post_init__(self):
@@ -159,26 +163,30 @@ class PlaybookConfig(BaseConfig):
 
 
 @dataclass
-class OverrideConfig(BaseConfig):
-    """Data class for an override config entry"""
+class ProjectConfig(BaseConfig):
+    """Data class for Project config"""
 
     # Project path relative to the repo
     project_path: str
 
     # Some applications / integrations have a schema file that needs to be handled
     artifact_path: Optional[str] = None
+    include_models: Optional[List[str]] = field(default_factory=list)
 
     dialect: Optional[str] = None
 
+    # KBTODO deprecate:model_allowlist: as part of playbooks revamp
     model_allowlist: Optional[List] = field(default_factory=list)
     playbooks: Optional[List[PlaybookConfig]] = field(default_factory=list)
 
 
 @dataclass
-class ProjectConfig(BaseConfig):
+class IntegrationConfig(BaseConfig):
     """Data class for a project item"""
 
-    include_all: Optional[bool] = True
+    include_all: Optional[bool] = False
+    include_projects: Optional[List[str]] = field(default_factory=list)
+    include_models: Optional[List[str]] = field(default_factory=list)
     artifact_path: Optional[str] = None
     dialect: Optional[str] = None
-    overrides: Optional[List[OverrideConfig]] = field(default_factory=list)
+    overrides: Optional[List[ProjectConfig]] = field(default_factory=list)
