@@ -4,8 +4,6 @@
 
 import asyncio
 import base64
-import importlib
-import inspect
 import io
 import json
 import os
@@ -103,95 +101,6 @@ def dump_dict_to_yaml_str(content: dict, yaml: Optional[YAML] = None) -> str:
     return str_io.getvalue()
 
 
-def get_root_dir_fullpath(current_filepath: str, root_dir_name: str):
-    """Get the full path of the root directory"""
-    return os.path.join(
-        f"/{root_dir_name}".join(
-            os.path.dirname(os.path.abspath(current_filepath)).split(root_dir_name)[:-1]
-        ),
-        root_dir_name,
-    )
-
-
-def find_subclasses_in_directory(
-    root_dir: str, base_class, exclude_dirs: List[str] = None
-):
-    """Find subclasses of a base class in modules in a root_dir"""
-    subclasses = []
-    filenames = find_files_with_suffix(root_dir, [".py"], exclude_dirs=exclude_dirs)
-    for py_file in filenames:
-        rel_py_file = py_file.split(f"{root_dir}/")[1]
-        module_name = rel_py_file.replace("/", ".").replace(".py", "")
-        try:
-            module = importlib.import_module(module_name)
-            for _, obj in inspect.getmembers(module):
-                if (
-                    inspect.isclass(obj)
-                    and issubclass(obj, base_class)
-                    and obj != base_class
-                    and obj not in subclasses
-                ):
-                    subclasses.append(obj)
-        except Exception as exc:  # pylint: disable=broad-except
-            logger.warning("Could not import module %s with %s", module_name, str(exc))
-    return subclasses
-
-
-def find_files_with_suffix(
-    root_dir: str,
-    suffixes: List[str],
-    exclude_dirs: Optional[List[str]] = None,
-):
-    """Find files with a suffix in a root directory"""
-    files = []
-    default_exclude_dirs = [
-        "__pycache__",
-        ".git",
-        "node_modules",
-        ".git",
-        ".venv",
-        "virtualenv",
-        ".virtualenv",
-        "venv",
-        "env",
-        "dist",
-        "migrations",
-        "tmp",
-        "temp",
-        "cache",
-        "dbt_packages",
-        "packages",
-        "Test",
-        "test",
-        "Tests",
-        "tests",
-        "e2e",
-    ]
-    all_exclude_dirs = (
-        exclude_dirs + default_exclude_dirs if exclude_dirs else default_exclude_dirs
-    )
-    exclude_dirs_pattern = re.compile(r"^(?:" + "|".join(all_exclude_dirs) + r")$")
-    for root, dirs, filenames in os.walk(root_dir, topdown=True):
-        dirs[:] = [d for d in dirs if not exclude_dirs_pattern.match(d)]
-        for filename in filenames:
-            full_filepath = os.path.join(root, filename)
-            if full_filepath.endswith(tuple(suffixes)):
-                files.append(full_filepath)
-    return files
-
-
-def deep_get_dict(dct, path=None):
-    """Get a value from a nested dict"""
-    if not path:
-        path = []
-    for key in path:
-        if key in dct:
-            dct = dct[key]
-        else:
-            return None
-    return dct
-
-
 def make_snake_case(string: str) -> str:
     """Convert a string to snake case"""
     return re.sub(r"[\s\-\.]+", "_", string).lower()
@@ -269,11 +178,6 @@ def fetch_schema(schema_url: str) -> dict:
     return get_schema_session().get(schema_url, timeout=(10, 10)).json()
 
 
-def sort_dict_by_keys(dct: dict) -> dict:
-    """Sort a dict by its keys"""
-    return dict(sorted(dct.items(), key=lambda x: x[0]))
-
-
 def sorted_yaml_dump(
     content: dict,
     stream: TextIO,
