@@ -16,6 +16,7 @@ from deepmerge import STRATEGY_END, Merger
 from jsonschema_rs import ValidationError as JsonValidationError
 from jsonschema_rs import validator_for as jsonschema_validator_for
 
+from opendapi.adapters.file import find_files_with_suffix
 from opendapi.adapters.git import ChangeTriggerEvent, GitCommitStasher
 from opendapi.cli.common import Schemas
 from opendapi.config import OpenDAPIConfig
@@ -25,7 +26,6 @@ from opendapi.utils import (
     YAML,
     convert_ruemelyaml_commentedmap_to_dict,
     fetch_schema,
-    find_files_with_suffix,
     prune_additional_properties,
     read_yaml_or_json,
 )
@@ -380,8 +380,9 @@ class BaseValidator(ABC):
             not self.MUST_GENERATE_EVEN_IF_ENTITY_TYPE_EXISTS
             and self.original_file_state
         ):
-            # If the entity type exists in the original file state, we don't want to generate a file
-            return {}
+            # If the entity type exists in the original file state,
+            # we don't want to generate a new file
+            return self.original_file_state
 
         base_gen_files = self._get_base_generated_files()
         if self.schema_to_prune_generated:
