@@ -8,7 +8,7 @@ import re
 from dataclasses import dataclass
 from typing import Dict, List
 from typing import Optional as OptionalType
-from typing import Set
+from typing import Set, Union
 
 import sentry_sdk
 from pyparsing import Dict as DictParser
@@ -26,21 +26,22 @@ from pyparsing import (
     nums,
 )
 
+from opendapi.adapters.file import find_files_with_suffix
 from opendapi.config import (
     construct_dapi_source_sink_from_playbooks,
     construct_owner_team_urn_from_playbooks,
     construct_project_full_path,
     get_project_path_from_full_path,
-    is_model_in_allowlist,
 )
-from opendapi.models import OverrideConfig, PlaybookConfig
-from opendapi.utils import find_files_with_suffix
+from opendapi.models import ProjectConfig
+from opendapi.validators.base import ValidationError
 from opendapi.validators.dapi.base.main import DapiValidator, ORMIntegration
 from opendapi.validators.dapi.models import ProjectInfo
+from opendapi.validators.dapi.parsers.ddl import SqlDialect, parse_ddl
 
 
 @dataclass
-class Column:
+class SchemaRbColumn:
     """Data class for a column in a table in a rails project schema."""
 
     column_type: str
@@ -57,7 +58,7 @@ class Column:
 
 
 @dataclass
-class Index:
+class SchemaRbIndex:
     """Data class for an index in a table in a rails project schema."""
 
     table_name: str
@@ -66,43 +67,16 @@ class Index:
 
 
 @dataclass
-class Table:  # pylint: disable=too-many-instance-attributes
+class SchemaRbTable:  # pylint: disable=too-many-instance-attributes
     """Data class for a table in a rails project schema."""
 
     table_name: str
     table_options: dict
-    parsed_columns: List[Column]
-    parsed_indices: List[Index]
-    project_full_path: str
-    schema_full_path: str
-    org_name_snakecase: str
-    playbooks: OptionalType[List[PlaybookConfig]] = None
-    is_allowlisted: bool = True
-
-    def construct_urn(self) -> str:
-        """Construct the URN for the table."""
-        return f"{self.org_name_snakecase}.activerecord.{self.project_name}.{self.table_name}"
-
-    def construct_datastores(self) -> List[str]:
-        """Get the datastores for the table."""
-        return DapiValidator.add_non_playbook_datastore_fields(
-            construct_dapi_source_sink_from_playbooks(self.playbooks, self.table_name)
-            if self.playbooks
-            else {"sources": [], "sinks": []}
-        )
-
-    def construct_team_urn(self) -> OptionalType[str]:
-        """Construct the team URN for the table."""
-        return (
-            construct_owner_team_urn_from_playbooks(
-                self.playbooks, self.table_name, self.schema_full_path
-            )
-            if self.playbooks
-            else None
-        )
+    parsed_columns: List[SchemaRbColumn]
+    parsed_indices: List[SchemaRbIndex]
 
     @property
-    def table_options_primary_keys(self) -> List[str]:
+    def _table_options_primary_keys(self) -> List[str]:
         """Get the primary keys in the table options."""
         if isinstance(self.table_options.get("primary_key"), str):
             return [self.table_options.get("primary_key")]
@@ -111,12 +85,12 @@ class Table:  # pylint: disable=too-many-instance-attributes
         return []
 
     @property
-    def columns(self) -> List[Column]:
+    def columns(self) -> List[SchemaRbColumn]:
         """Get the columns in the table."""
         id_option = self.table_options.get("id", "true")
         pk_col_name = None
         pk_col_type = None
-        if primary_keys := self.table_options_primary_keys:
+        if primary_keys := self._table_options_primary_keys:
             if len(primary_keys) == 1:
                 pk_col_name = primary_keys[0]
                 pk_col_type = "bigint" if id_option in {"true", "false"} else id_option
@@ -140,7 +114,7 @@ class Table:  # pylint: disable=too-many-instance-attributes
             columns_by_name[pk_col_name].column_options["primary_key"] = "true"
             columns_by_name[pk_col_name].column_options["null"] = "false"
         elif pk_col_name and pk_col_type:
-            columns_by_name[pk_col_name] = Column(
+            columns_by_name[pk_col_name] = SchemaRbColumn(
                 pk_col_type,
                 pk_col_name,
                 {"null": "false", "primary_key": "true"},
@@ -151,7 +125,7 @@ class Table:  # pylint: disable=too-many-instance-attributes
     @property
     def primary_keys(self) -> List[str]:
         """Get the primary keys in the table."""
-        if table_option_primary_keys := self.table_options_primary_keys:
+        if table_option_primary_keys := self._table_options_primary_keys:
             return table_option_primary_keys
 
         # Case when the primary key is not specified in the table options
@@ -161,16 +135,79 @@ class Table:  # pylint: disable=too-many-instance-attributes
                 columns_with_primary_key.append(column.column_name)
         return columns_with_primary_key
 
-    @property
-    def project_name(self) -> str:
-        """Get the name of the project."""
-        return os.path.basename(self.project_full_path)
+
+@dataclass
+class StructureSqlColumn:
+    """Data class for a column in a table in a SQL schema."""
+
+    column_name: str
+    column_type: str
+    is_nullable: bool
+
+    def for_dapi(self) -> dict:
+        """Return the column as a dictionary for DAPI."""
+        return {
+            "name": self.column_name,
+            "data_type": self.column_type,
+            "is_nullable": self.is_nullable,
+        }
+
+
+@dataclass
+class StructuredSqlTable:
+    """Data class for a table in a SQL schema."""
+
+    table_name: str
+    columns: List[StructureSqlColumn]
+    primary_keys: List[str]
 
 
 @dataclass
 class ActiveRecordProjectInfo(ProjectInfo):
     """Data class for a rails project information"""
 
+    # Required for SQL artifacts, not used for schema.rb artifacts
+    dialect: OptionalType[SqlDialect] = None
+
+    @property
+    def project_name(self) -> str:
+        """Get the name of the project."""
+        # root is the project - so we set that to the project name
+        if self.root_path.strip("/") == self.full_path.strip("/"):
+            return os.path.basename(self.full_path)
+
+        # if not, we use the relative project_path
+        proj_path = get_project_path_from_full_path(self.root_path, self.full_path)
+        return proj_path.strip("/").replace("/", ".")
+
+    def is_sql_artifact(self) -> bool:
+        """Check if the artifact is a SQL artifact."""
+        return self.artifact_full_path.endswith(".sql")
+
+    def construct_urn(self, table_name: str) -> str:
+        """Construct the URN for the table."""
+        return (
+            f"{self.org_name_snakecase}.activerecord.{self.project_name}.{table_name}"
+        )
+
+    def construct_datastores(self, table_name: str) -> List[str]:
+        """Construct the datastores for the table."""
+        return DapiValidator.add_non_playbook_datastore_fields(
+            construct_dapi_source_sink_from_playbooks(self.config.playbooks, table_name)
+            if self.config.playbooks
+            else {"sources": [], "sinks": []}
+        )
+
+    def construct_team_urn(self, table_name: str) -> OptionalType[str]:
+        """Construct the team URN for the table."""
+        return (
+            construct_owner_team_urn_from_playbooks(
+                self.config.playbooks, table_name, self.artifact_full_path
+            )
+            if self.config.playbooks
+            else None
+        )
+
     @functools.cached_property
     def missing_tables(self) -> Set[str]:
         """Get the expected number of tables in the schema."""
@@ -183,9 +220,39 @@ class ActiveRecordProjectInfo(ProjectInfo):
             }
 
     @functools.cached_property
-    def tables(self) -> List[Table]:
+    def tables(self) -> List[Union[SchemaRbTable, StructuredSqlTable]]:
         """Get the tables in the schema."""
+        if self.is_sql_artifact():
+            return self.parse_sql_schema()
 
+        return self.parse_rb_schema()
+
+    def parse_sql_schema(self) -> List[StructuredSqlTable]:
+        """Parse the structure.sql file."""
+        with open(self.artifact_full_path, "r", encoding="utf-8") as file:
+            ddl = file.read()
+
+        ddl_tables = parse_ddl(ddl, self.dialect)
+        tables = []
+        for table in ddl_tables:
+            tables.append(
+                StructuredSqlTable(
+                    table.fq_name,
+                    [
+                        StructureSqlColumn(
+                            column.name,
+                            column.type,
+                            column.is_nullable,
+                        )
+                        for column in table.columns
+                    ],
+                    table.primary_key.columns if table.primary_key else [],
+                )
+            )
+        return tables
+
+    def parse_rb_schema(self) -> List[SchemaRbTable]:
+        """Parse the schema.rb file."""
         # Define pyparsing elements
         integer_or_float = Word(nums + ".")
         boolean = Literal("true") | Literal("false")
@@ -345,7 +412,7 @@ class ActiveRecordProjectInfo(ProjectInfo):
                 # construct obvious columns
                 for column in table["columns"]:
                     if "column_name" in column:
-                        columns[column["column_name"]] = Column(
+                        columns[column["column_name"]] = SchemaRbColumn(
                             column["column_type"],
                             column["column_name"],
                             column["column_options"],
@@ -366,7 +433,7 @@ class ActiveRecordProjectInfo(ProjectInfo):
                         table_name
                     ):
                         indices.append(
-                            Index(
+                            SchemaRbIndex(
                                 str(index["table_name"]),
                                 dict(index["index_columns"]),
                                 dict(index["index_options"]),
@@ -377,7 +444,7 @@ class ActiveRecordProjectInfo(ProjectInfo):
                 for column in table["columns"]:
                     if "index_columns" in column:
                         indices.append(
-                            Index(
+                            SchemaRbIndex(
                                 table_name,
                                 dict(column["index_columns"]),
                                 dict(column["index_options"]),
@@ -385,20 +452,11 @@ class ActiveRecordProjectInfo(ProjectInfo):
                         )
 
                 tables.append(
-                    Table(
+                    SchemaRbTable(
                         str(table_name),
                         dict(table_options),
                         list(columns.values()),
                         indices,
-                        self.full_path,
-                        self.artifact_full_path,
-                        self.org_name_snakecase,
-                        self.override.playbooks,
-                        is_model_in_allowlist(
-                            str(table_name),
-                            self.artifact_full_path,
-                            self.override.model_allowlist,
-                        ),
                     )
                 )
         return tables
@@ -410,25 +468,13 @@ class ActiveRecordDapiValidator(DapiValidator[ActiveRecordProjectInfo]):
     """
 
     INTEGRATION_NAME = ORMIntegration.ACTIVERECORD
-    SCHEMA_FILE_PATH_SUFFIX = "db/schema.rb"
-
-    def _assert_schema_files_exist(self, projects: List[ActiveRecordProjectInfo]):
-        """Assert that the schema files exist."""
-        errors = []
-        for project in projects:
-            if not os.path.exists(project.artifact_full_path):
-                errors.append(
-                    f"ActiveRecord Schema file {project.artifact_full_path} "
-                    f"not found for project {project.full_path}"
-                )
-        if errors:
-            raise FileNotFoundError("/n".join(errors))
+    DEFAULT_ARTIFACT_PATH = "db/schema.rb"
 
     def get_all_projects(self) -> List[ActiveRecordProjectInfo]:
         """Generate a list of all projects that this validator should check"""
 
         schema_file_suffix = (
-            f"/{self.settings.artifact_path or self.SCHEMA_FILE_PATH_SUFFIX}"
+            f"/{self.integration_config.artifact_path or self.DEFAULT_ARTIFACT_PATH}"
         )
         all_schema_files = find_files_with_suffix(self.root_dir, [schema_file_suffix])
 
@@ -438,37 +484,64 @@ class ActiveRecordDapiValidator(DapiValidator[ActiveRecordProjectInfo]):
             project_path = get_project_path_from_full_path(self.root_dir, base_dir)
             artifact_path = get_project_path_from_full_path(base_dir, schema_file)
 
-            override = OverrideConfig(
-                project_path=project_path, artifact_path=artifact_path
+            override = ProjectConfig(
+                project_path=project_path,
+                artifact_path=artifact_path,
+                dialect=self.integration_config.dialect,
+                include_models=self.integration_config.include_models,
             )
 
             projects.append(self.get_project(override))
 
         return projects
 
-    def get_project(self, override_config: OverrideConfig) -> ActiveRecordProjectInfo:
-        """Given a project override config, return an ProjectConfig object"""
+    def get_project(self, project_config: ProjectConfig) -> ActiveRecordProjectInfo:
+        """Given a project config, return  object"""
 
-        override = copy.copy(override_config)
+        copy_project_config = copy.copy(project_config)
         project_full_path = construct_project_full_path(
-            self.root_dir, override.project_path
+            self.root_dir, copy_project_config.project_path
         )
 
-        override.artifact_path = (
-            override.artifact_path or f"{self.SCHEMA_FILE_PATH_SUFFIX}"
+        copy_project_config.artifact_path = (
+            copy_project_config.artifact_path or f"{self.DEFAULT_ARTIFACT_PATH}"
         )
 
+        copy_project_config.include_models = (
+            copy_project_config.include_models or self.integration_config.include_models
+        )
+
+        dialect_value = copy_project_config.dialect or self.integration_config.dialect
+        dialect = SqlDialect(dialect_value) if dialect_value else None
+
         return ActiveRecordProjectInfo(
             org_name_snakecase=self.config.org_name_snakecase,
             root_path=self.root_dir,
-            override=override,
+            config=copy_project_config,
             full_path=project_full_path,
-            artifact_full_path=os.path.join(project_full_path, override.artifact_path),
+            artifact_full_path=os.path.join(
+                project_full_path, copy_project_config.artifact_path
+            ),
+            dialect=dialect,
         )
 
+    def assert_dialect_for_sql_artifact(self, projects: List[ActiveRecordProjectInfo]):
+        """Assert that the dialect is set for the SQL artifact"""
+        errors = []
+
+        for project in projects:
+            if project.is_sql_artifact() and project.dialect is None:
+                errors.append(
+                    f"Dialect not found for project {project.full_path}. "
+                    "Please specify the dialect in the project config."
+                )
+        if errors:
+            raise ValidationError("\n".join(errors))
+
     def validate_projects(self, projects: List[ActiveRecordProjectInfo]):
         """Validate the projects"""
-        self._assert_schema_files_exist(projects)
+        self.assert_artifact_files_exist(projects)
+        self.assert_dialect_for_sql_artifact(projects)
 
     def _get_base_generated_files(self) -> Dict[str, Dict]:
         result = {}
@@ -483,20 +556,26 @@ class ActiveRecordDapiValidator(DapiValidator[ActiveRecordProjectInfo]):
                 )
 
             for table in project.tables:
-                if table.is_allowlisted:
+                if project.is_model_included(
+                    table.table_name, project.artifact_full_path
+                ):
                     dapi_location = project.construct_dapi_location(table.table_name)
                     generated_fields = [field.for_dapi() for field in table.columns]
-                    dapi_urn = table.construct_urn()
+                    dapi_urn = project.construct_urn(table.table_name)
                     result[dapi_location] = (
                         self.add_default_non_generated_schema_portions(
                             {
                                 "urn": dapi_urn,
-                                "owner_team_urn": table.construct_team_urn(),
-                                "datastores": table.construct_datastores(),
+                                "owner_team_urn": project.construct_team_urn(
+                                    table.table_name
+                                ),
+                                "datastores": project.construct_datastores(
+                                    table.table_name
+                                ),
                                 "fields": generated_fields,
                                 "primary_key": table.primary_keys,
                                 "context": {
-                                    "service": table.project_name,
+                                    "service": project.project_name,
                                     "integration": "activerecord",
                                     "rel_model_path": os.path.relpath(
                                         project.artifact_full_path,
