@@ -9,9 +9,17 @@ from collections import Counter
 from functools import cached_property
 from typing import Dict, Generic, List, Tuple, Type, TypeVar, Union
 
+from opendapi.adapters.file import text_file_loader
 from opendapi.cli.utils import load_missing_dapis_from_cache
+from opendapi.config import get_project_path_from_full_path
 from opendapi.defs import DAPI_SUFFIX, OPENDAPI_SPEC_URL, OpenDAPIEntity, ORMIntegration
-from opendapi.models import ConfigParam, OverrideConfig, PlaybookConfig, ProjectConfig
+from opendapi.models import (
+    ConfigParam,
+    IntegrationConfig,
+    PlaybookConfig,
+    ProjectConfig,
+)
+from opendapi.selector import filter_candidates_by_selectors
 from opendapi.utils import sort_dapi_fields
 from opendapi.validators.base import (
     BaseValidator,
@@ -184,13 +192,13 @@ class BaseDapiValidator(BaseValidator):
             )
 
     @cached_property
-    def settings(self) -> ProjectConfig:
-        """Get the settings from the config file for this integration"""
-        settings = copy.deepcopy(
-            self.config.get_integration_settings(self.INTEGRATION_NAME, self.runtime)
+    def integration_config(self) -> IntegrationConfig:
+        """Get the config for this integration"""
+        integration_config = copy.deepcopy(
+            self.config.get_integration_config(self.INTEGRATION_NAME, self.runtime)
         )
 
-        override_config = settings.get(ConfigParam.PROJECTS.value, {}).get(
+        override_config = integration_config.get(ConfigParam.PROJECTS.value, {}).get(
             ConfigParam.OVERRIDES.value, []
         )
 
@@ -201,11 +209,15 @@ class BaseDapiValidator(BaseValidator):
                 for playbook in override.get(ConfigParam.PLAYBOOKS.value, [])
             ]
             override[ConfigParam.PLAYBOOKS.value] = playbooks
-            overrides.append(OverrideConfig.from_dict(override))
+            overrides.append(ProjectConfig.from_dict(override))
 
-        settings[ConfigParam.PROJECTS.value][ConfigParam.OVERRIDES.value] = overrides
+        integration_config[ConfigParam.PROJECTS.value][
+            ConfigParam.OVERRIDES.value
+        ] = overrides
 
-        return ProjectConfig.from_dict(settings[ConfigParam.PROJECTS.value])
+        return IntegrationConfig.from_dict(
+            integration_config[ConfigParam.PROJECTS.value]
+        )
 
     def validate_content(self, file: str, content: Dict, fileset: FileSet):
         """Validate the content of the files"""
@@ -452,30 +464,66 @@ class DapiValidator(BaseDapiValidator, Generic[ProjectInfoType]):
 
     def selected_projects(self, validate: bool = True) -> List[ProjectInfoType]:
         """Get the selected projects"""
-        projects = {}
+        projects_by_fullpath: Dict[str, ProjectInfoType] = {}
 
-        if self.settings.include_all:
+        if (
+            self.integration_config.include_all
+            or self.integration_config.include_projects
+        ):
             for project in self.get_all_projects():
-                projects[project.full_path] = project
+                projects_by_fullpath[project.full_path] = project
 
-        for override in self.settings.overrides:
+        for override in self.integration_config.overrides:
             project = self.get_project(override)
-            projects[project.full_path] = project
+            projects_by_fullpath[project.full_path] = project
 
-        projects = list(projects.values())
+        projects: List[ProjectInfoType] = list(projects_by_fullpath.values())
+        project_rel_paths = [
+            get_project_path_from_full_path(self.root_dir, project.full_path)
+            for project in projects
+        ]
+
+        filtered_project_paths = filter_candidates_by_selectors(
+            project_rel_paths,
+            self.integration_config.include_projects,
+            file_loader=lambda rel_path: text_file_loader(
+                os.path.join(self.root_dir, rel_path)
+            ),
+            include_all_if_unspecified=True,
+        )
+
+        filtered_projects = [
+            proj
+            for proj in projects
+            if get_project_path_from_full_path(self.root_dir, proj.full_path)
+            in filtered_project_paths
+        ]
 
         if validate:
-            self.validate_projects(projects)
+            self.validate_projects(filtered_projects)
 
-        return projects
+        return filtered_projects
+
+    def assert_artifact_files_exist(self, projects: List[ProjectInfoType]):
+        """Assert that the artifact files exist"""
+        errors = []
+        for project in projects:
+            artifact_paths = project.artifact_full_path.split(",")
+            for artifact_path in artifact_paths:
+                if not os.path.exists(artifact_path):
+                    errors.append(
+                        f"Artifact file {artifact_path} not found for project {project.full_path}"
+                    )
+        if errors:
+            raise FileNotFoundError("\n".join(errors))
 
     @abstractmethod
     def get_all_projects(self) -> List[ProjectInfoType]:
         """Generate a list of all projects that this validator should check"""
 
     @abstractmethod
-    def get_project(self, override_config: OverrideConfig) -> ProjectInfoType:
-        """Given a project override config, return an ProjectConfig object"""
+    def get_project(self, project_config: ProjectConfig) -> ProjectInfoType:
+        """Given a project config, return an ProjectInfo object"""
 
     @abstractmethod
     def validate_projects(self, projects: List[ProjectInfoType]):
