@@ -9,16 +9,16 @@ from enum import Enum
 from functools import cached_property
 from typing import Dict, List, Optional, Tuple
 
+from opendapi.adapters.file import find_files_with_suffix
 from opendapi.config import (
     construct_dapi_source_sink_from_playbooks,
     construct_owner_team_urn_from_playbooks,
     construct_project_full_path,
     get_project_path_from_full_path,
-    is_model_in_allowlist,
 )
 from opendapi.logging import logger
-from opendapi.models import OverrideConfig
-from opendapi.utils import find_files_with_suffix, read_yaml_or_json
+from opendapi.models import ProjectConfig
+from opendapi.utils import read_yaml_or_json
 from opendapi.validators.dapi.base.main import DapiValidator, ORMIntegration
 from opendapi.validators.dapi.mixins.dbt_cloud import DBTCloudMixin, DBTCloudProject
 from opendapi.validators.dapi.models import ProjectInfo
@@ -99,14 +99,6 @@ class DBTProjectInfo(ProjectInfo):
         """Get the merged catalog"""
         return DBTCloudProject.merge_catalogs(self.raw_catalog, self.production_catalog)
 
-    def filter_dapis(self, dapis: Dict[str, Dict]) -> Dict[str, Dict]:
-        """Get the owned DAPIs"""
-        return {
-            filepath: dapi
-            for filepath, dapi in dapis.items()
-            if dapi.get("context", {}).get("service") == self.name
-        }
-
     @property
     def has_cloud_artifacts(self) -> bool:
         """Check if the project has artifacts"""
@@ -331,9 +323,9 @@ class DBTModel:
         """Construct the datastores"""
         datastores = (
             construct_dapi_source_sink_from_playbooks(
-                self.project.override.playbooks, self.name
+                self.project.config.playbooks, self.name
             )
-            if self.project.override.playbooks
+            if self.project.config.playbooks
             else {"sources": [], "sinks": []}
         )
         self.perform_reconciliation_for_datastore_sources(
@@ -345,9 +337,9 @@ class DBTModel:
         """Construct the owner team urn"""
         return (
             construct_owner_team_urn_from_playbooks(
-                self.project.override.playbooks, self.name, self.model_path
+                self.project.config.playbooks, self.name, self.model_path
             )
-            if self.project.override.playbooks
+            if self.project.config.playbooks
             else None
         )
 
@@ -387,7 +379,7 @@ class DbtDapiValidator(DapiValidator[DBTProjectInfo], DBTCloudMixin):
         projects = []
         dbt_config_files = find_files_with_suffix(
             self.root_dir,
-            [f"/{self.settings.artifact_path or DBT_CONFIG_YML}"],
+            [f"/{self.integration_config.artifact_path or DBT_CONFIG_YML}"],
             exclude_dirs=["dbt_packages"],
         )
 
@@ -395,27 +387,36 @@ class DbtDapiValidator(DapiValidator[DBTProjectInfo], DBTCloudMixin):
             # glob for a file called dbt_project.yml within the dbt project
             project_full_path = os.path.normpath(os.path.dirname(config_full_path))
 
-            override = OverrideConfig(
+            override = ProjectConfig(
                 project_path=get_project_path_from_full_path(
                     self.root_dir, project_full_path
                 ),
                 artifact_path=DBT_ARTIFACTS_DIR,
+                include_models=self.integration_config.include_models,
             )
 
             projects.append(self.get_project(override))
 
         return projects
 
-    def get_project(self, override_config: OverrideConfig) -> DBTProjectInfo:
-        """Given a project override config, return an ProjectConfig object"""
+    def get_project(self, project_config: ProjectConfig) -> DBTProjectInfo:
+        """Given a project config, return ProjectInfo object"""
 
-        override = copy.deepcopy(override_config)
+        copy_project_config = copy.deepcopy(project_config)
         project_full_path = construct_project_full_path(
-            self.root_dir, override.project_path
+            self.root_dir, copy_project_config.project_path
         )
 
-        override.artifact_path = override.artifact_path or DBT_ARTIFACTS_DIR
-        artifact_full_path = os.path.join(project_full_path, override.artifact_path)
+        copy_project_config.artifact_path = (
+            copy_project_config.artifact_path or DBT_ARTIFACTS_DIR
+        )
+        copy_project_config.include_models = (
+            copy_project_config.include_models or self.integration_config.include_models
+        )
+
+        artifact_full_path = os.path.join(
+            project_full_path, copy_project_config.artifact_path
+        )
 
         config_full_path = os.path.join(project_full_path, DBT_CONFIG_YML)
         dbt_config = read_yaml_or_json(config_full_path)
@@ -425,7 +426,7 @@ class DbtDapiValidator(DapiValidator[DBTProjectInfo], DBTCloudMixin):
             name=dbt_config["name"],
             dbt_config=dbt_config,
             root_path=self.root_dir,
-            override=override_config,
+            config=copy_project_config,
             full_path=os.path.normpath(project_full_path),
             artifact_full_path=artifact_full_path,
         )
@@ -520,12 +521,11 @@ class DbtDapiValidator(DapiValidator[DBTProjectInfo], DBTCloudMixin):
                         name=model["name"],
                         unique_id=unique_model_name,
                         project=project,
-                        is_allowlisted=is_model_in_allowlist(
+                        is_allowlisted=project.is_model_included(
                             model["name"],
                             os.path.join(
                                 project.full_path, model["original_file_path"]
                             ),
-                            project.override.model_allowlist,
                         ),
                     )
                     dbt_models.append(dbt_model)
