@@ -2,7 +2,7 @@
 
 from typing import Dict, Optional
 
-from opendapi.validators.dapi.base import BaseDapiValidator, ORMIntegration
+from opendapi.validators.dapi.base.main import BaseDapiValidator, ORMIntegration
 from opendapi.validators.defs import FileSet
 
 
