@@ -19,7 +19,6 @@ import requests
 from opendapi.cli.common import (
     highlight_message,
     print_cli_output,
-    print_encoded_breadcrumbs,
 )
 from opendapi.defs import CommitType
 from opendapi.logging import logger
@@ -727,7 +726,6 @@ class DBTCloudMixin:
                         #       goes to sentry.
 
                         if self._fast_fail:
-                            print_encoded_breadcrumbs(error_message)
                             raise RuntimeError(highlight_message(error_message))
 
                         # if we are not fast failing, we want to check
@@ -749,7 +747,6 @@ class DBTCloudMixin:
                                     "No other fallback runs were found for this commit on dbt cloud.",
                                 ]
                             )
-                            print_encoded_breadcrumbs(error_message)
                             raise RuntimeError(highlight_message(error_message))
 
                         print_cli_output(
@@ -891,6 +888,5 @@ class DBTCloudMixin:
         )
         for project_id, run in runs_by_project.items():
             error_message += f"Project ID: {project_id}, Run URL: {DBTCloudProject.build_run_html_url(run)}\n"
-        print_encoded_breadcrumbs(error_message)
         print_cli_output(highlight_message(error_message))
         return False
