@@ -28,15 +28,14 @@ from pyparsing import (
     restOfLine,
 )
 
+from opendapi.adapters.file import find_files_with_suffix
 from opendapi.config import (
     construct_dapi_source_sink_from_playbooks,
     construct_owner_team_urn_from_playbooks,
     construct_project_full_path,
     get_project_path_from_full_path,
-    is_model_in_allowlist,
 )
-from opendapi.models import OverrideConfig, PlaybookConfig
-from opendapi.utils import find_files_with_suffix
+from opendapi.models import PlaybookConfig, ProjectConfig
 from opendapi.validators.dapi.base.main import DapiValidator, ORMIntegration
 from opendapi.validators.dapi.models import ProjectInfo
 
@@ -407,11 +406,10 @@ class PrismaProjectInfo(ProjectInfo):
                     project_full_path=self.full_path,
                     schema_full_path=self.artifact_full_path,
                     org_name_snakecase=self.org_name_snakecase,
-                    playbooks=self.override.playbooks,
-                    is_allowlisted=is_model_in_allowlist(
+                    playbooks=self.config.playbooks,
+                    is_allowlisted=self.is_model_included(
                         table.table_name,
                         self.artifact_full_path,
-                        self.override.model_allowlist,
                     ),
                 )
             )
@@ -432,43 +430,36 @@ class PrismaDapiValidator(DapiValidator[PrismaProjectInfo]):
 
     INTEGRATION_NAME = ORMIntegration.PRISMA
 
-    SCHEMA_FILE_PATH_SUFFIX = ".prisma"
+    DEFAULT_ARTIFACT_PATH = ".prisma"
     # This is used by the npm prisma-multischema package. We will exclude the
     # subschemas directory from the search and parse only the combined schema file.
-    SCHEMA_FILE_EXCLUDE_DIRS = ["subschemas"]
+    EXCLUDE_DIRS_FOR_AUTODISCOVERY = ["subschemas"]
 
-    def _assert_schema_files_exist(self, projects: List[PrismaProjectInfo]):
-        """Assert that the schema files exist."""
-        errors = []
-        for project in projects:
-            if not os.path.exists(project.full_path):
-                errors.append(
-                    f"Prisma Schema file {project.full_path} "
-                    f"not found for project {project.full_path}"
-                )
-        if errors:
-            raise FileNotFoundError("/n".join(errors))
+    def get_project(self, project_config: ProjectConfig) -> PrismaProjectInfo:
+        """Given a project config, return ProjectInfo object"""
 
-    def get_project(self, override_config: OverrideConfig) -> PrismaProjectInfo:
-        """Given an project override configuration, return the project config"""
-
-        override = copy.deepcopy(override_config)
+        copy_project_config = copy.deepcopy(project_config)
         project_full_path = construct_project_full_path(
-            self.root_dir, override.project_path
+            self.root_dir, copy_project_config.project_path
         )
 
-        override.artifact_path = (
-            override.artifact_path
-            or self.settings.artifact_path
-            or f"schema.{self.SCHEMA_FILE_PATH_SUFFIX}"
+        copy_project_config.artifact_path = (
+            copy_project_config.artifact_path
+            or self.integration_config.artifact_path
+            or f"schema.{self.DEFAULT_ARTIFACT_PATH}"
+        )
+        copy_project_config.include_models = (
+            copy_project_config.include_models or self.integration_config.include_models
         )
 
         return PrismaProjectInfo(
             org_name_snakecase=self.config.org_name_snakecase,
             root_path=self.root_dir,
-            override=override,
+            config=copy_project_config,
             full_path=project_full_path,
-            artifact_full_path=os.path.join(project_full_path, override.artifact_path),
+            artifact_full_path=os.path.join(
+                project_full_path, copy_project_config.artifact_path
+            ),
         )
 
     def get_all_projects(self) -> List[PrismaProjectInfo]:
@@ -476,8 +467,8 @@ class PrismaDapiValidator(DapiValidator[PrismaProjectInfo]):
 
         all_schema_files = find_files_with_suffix(
             self.root_dir,
-            [self.settings.artifact_path or f"{self.SCHEMA_FILE_PATH_SUFFIX}"],
-            exclude_dirs=self.SCHEMA_FILE_EXCLUDE_DIRS,
+            [self.integration_config.artifact_path or f"{self.DEFAULT_ARTIFACT_PATH}"],
+            exclude_dirs=self.EXCLUDE_DIRS_FOR_AUTODISCOVERY,
         )
 
         projects = []
@@ -491,16 +482,18 @@ class PrismaDapiValidator(DapiValidator[PrismaProjectInfo]):
 
             project_path = get_project_path_from_full_path(self.root_dir, schema_path)
 
-            override = OverrideConfig(
-                project_path=project_path, artifact_path=artifact_path
+            config = ProjectConfig(
+                project_path=project_path,
+                artifact_path=artifact_path,
+                include_models=self.integration_config.include_models,
             )
-            projects.append(self.get_project(override))
+            projects.append(self.get_project(config))
 
         return projects
 
     def validate_projects(self, projects: List[PrismaProjectInfo]):
         """Verify that all projects and their schema files exist"""
-        self._assert_schema_files_exist(projects)
+        self.assert_artifact_files_exist(projects)
 
     def _get_base_generated_files(self) -> Dict[str, Dict]:
         result = {}
@@ -534,11 +527,11 @@ if __name__ == "__main__":  # pragma: no cover
     import sys
     from pprint import pprint
 
-    ovr_config = OverrideConfig(project_path="test_app")
+    proj_cfg = ProjectConfig(project_path="test_app")
 
     pprint(
         PrismaProjectInfo(
-            override=ovr_config,
+            config=proj_cfg,
             full_path=None,
             root_path="test_root",
             artifact_full_path=sys.argv[1],
