@@ -16,15 +16,14 @@ from google.protobuf import descriptor_pb2
 from google.protobuf.descriptor import FieldDescriptor
 from grpc_tools import protoc
 
+from opendapi.adapters.file import find_files_with_suffix
 from opendapi.config import (
     construct_dapi_source_sink_from_playbooks,
     construct_owner_team_urn_from_playbooks,
     construct_project_full_path,
-    is_model_in_allowlist,
 )
 from opendapi.defs import OPENDAPI_SPEC_URL
-from opendapi.models import OverrideConfig
-from opendapi.utils import find_files_with_suffix
+from opendapi.models import ProjectConfig
 from opendapi.validators.dapi.base.main import DapiValidator, ORMIntegration
 from opendapi.validators.dapi.models import ProjectInfo
 from opendapi.validators.defs import IntegrationType
@@ -424,7 +423,7 @@ class ProtobufProjectInfo(ProjectInfo):
         syntax: str,
     ) -> Dict:
 
-        project_path = self.override.project_path
+        project_path = self.config.project_path
         project_path = project_path.replace("/", ".")
         project_path = project_path[:-1] if project_path.endswith(".") else project_path
         project_path = "" if self.full_path == self.root_path else f"{project_path}"
@@ -447,19 +446,19 @@ class ProtobufProjectInfo(ProjectInfo):
                 "primary_key": [],
                 "owner_team_urn": (
                     construct_owner_team_urn_from_playbooks(
-                        self.override.playbooks,
+                        self.config.playbooks,
                         qualified_table_name,
                         absolute_proto_filename,
                     )
-                    if self.override.playbooks
+                    if self.config.playbooks
                     else None
                 ),
                 "datastores": ProtobufDapiValidator.add_non_playbook_datastore_fields(
                     construct_dapi_source_sink_from_playbooks(
-                        self.override.playbooks,
+                        self.config.playbooks,
                         qualified_table_name,
                     )
-                    if self.override.playbooks
+                    if self.config.playbooks
                     else {"sources": [], "sinks": []}
                 ),
                 "fields": self._get_dapi_fields_for_message(message),
@@ -485,20 +484,6 @@ class ProtobufProjectInfo(ProjectInfo):
                 f"The following packages were not found during compilation: {not_seen_str}"
             )
 
-        standardized_package_allowlist = []
-        for entry in self.override.model_allowlist:
-
-            # models may be prefixed by package, so we remove the leading
-            # period in this scenario
-            if not entry.startswith("path:"):
-                entry = (
-                    "!" + entry[1:].lstrip("\\.")
-                    if entry.startswith("!")
-                    else entry.lstrip("\\.")
-                )
-
-            standardized_package_allowlist.append(entry)
-
         return {
             self.construct_dapi_location(qualified_table_name): self._create_dapi(
                 message,
@@ -515,16 +500,13 @@ class ProtobufProjectInfo(ProjectInfo):
             # these are just the top levels, so good there
             for message in file_proto.message_type
             # make sure that we consider the allow/exclude list
-            if is_model_in_allowlist(
-                model_name=(
-                    qualified_table_name := self._get_qualified_table_name(message)
-                ),
-                model_path=(
+            if self.is_model_included(
+                (qualified_table_name := self._get_qualified_table_name(message)),
+                (
                     absolute_proto_filename := self._get_absolute_filename(
                         file_proto.name
                     )
                 ),
-                model_allowlist=standardized_package_allowlist,
             )
         }
 
@@ -595,10 +577,10 @@ class ProtobufDapiValidator(DapiValidator[ProtobufProjectInfo]):
         """
         raise RuntimeError("get_all_projects is not supported for Protobuf")
 
-    def get_project(self, override_config: OverrideConfig) -> ProtobufProjectInfo:
-        """Given a project override config, return an ProjectConfig object"""
+    def get_project(self, project_config: ProjectConfig) -> ProtobufProjectInfo:
+        """Given a project config, return ProjectInfo object"""
 
-        override = copy.deepcopy(override_config)
+        copy_project_config = copy.deepcopy(project_config)
         # proto output does not include leading dots, but those are valid,
         # so we remove them for consistency
         # NOTE not existing or the empty string is valid, since that is how we refer
@@ -607,16 +589,35 @@ class ProtobufDapiValidator(DapiValidator[ProtobufProjectInfo]):
         #      for protobuf, since there is no anchor, the project path serves as the anchor,
         #      and all of the proto packages are meant to go to the same location - so we handle them together.
         proto_package_names = {
-            package.lstrip(".") for package in (override.artifact_path or "").split(",")
+            package.lstrip(".")
+            for package in (copy_project_config.artifact_path or "").split(",")
         }
         project_full_path = construct_project_full_path(
-            self.root_dir, override.project_path
+            self.root_dir, copy_project_config.project_path
         )
+        copy_project_config.include_models = (
+            copy_project_config.include_models or self.integration_config.include_models
+        )
+        # convert the model allowlist to the new format
+        new_model_allowlist = []
+        for entry in copy_project_config.model_allowlist:
+
+            # models may be prefixed by package, so we remove the leading
+            # period in this scenario
+            if not entry.startswith("path:"):
+                entry = (
+                    "!" + entry[1:].lstrip("\\.")
+                    if entry.startswith("!")
+                    else entry.lstrip("\\.")
+                )
+            new_model_allowlist.append(entry)
+
+        copy_project_config.model_allowlist = new_model_allowlist
 
         return ProtobufProjectInfo(
             org_name_snakecase=self.config.org_name_snakecase,
             root_path=self.root_dir,
-            override=override,
+            config=copy_project_config,
             full_path=project_full_path,
             proto_package_names=set(proto_package_names),
         )
