@@ -10,15 +10,14 @@ from functools import cached_property
 from multiprocessing import Pipe, Process, connection
 from typing import TYPE_CHECKING, Dict, List
 
+from opendapi.adapters.file import find_subclasses_in_directory
 from opendapi.config import (
     construct_dapi_source_sink_from_playbooks,
     construct_owner_team_urn_from_playbooks,
     construct_project_full_path,
-    is_model_in_allowlist,
 )
 from opendapi.logging import logger
-from opendapi.models import OverrideConfig
-from opendapi.utils import find_subclasses_in_directory
+from opendapi.models import ProjectConfig
 from opendapi.validators.dapi.base.main import ORMIntegration
 from opendapi.validators.dapi.base.runtime import RuntimeDapiValidator
 from opendapi.validators.dapi.models import ProjectInfo
@@ -88,7 +87,7 @@ class PynamodbProjectInfo(ProjectInfo):
         base_classes = []
         sys.path.append(self.full_path)
 
-        for import_string in self.override.artifact_path.split(","):
+        for import_string in self.config.artifact_path.split(","):
             import_string = import_string.strip()
 
             if ":" in import_string:
@@ -133,7 +132,7 @@ class PynamodbProjectInfo(ProjectInfo):
         except Exception:
             logger.error(
                 "Error generating tables info under %s in %s",
-                self.override.artifact_path,
+                self.config.artifact_path,
                 self.full_path,
             )
             raise
@@ -151,7 +150,7 @@ class PynamodbProjectInfo(ProjectInfo):
 
         if process.exitcode:
             raise ImportError(
-                f"Error generating tables: {self.override.artifact_path} in {self.full_path}"
+                f"Error generating tables: {self.config.artifact_path} in {self.full_path}"
             )
 
         # Receive the tables from the child process
@@ -174,25 +173,31 @@ class PynamodbDapiValidator(RuntimeDapiValidator[PynamodbProjectInfo]):
 
     def selected_projects(self, validate: bool = True) -> List[PynamodbProjectInfo]:
         """Get the selected projects"""
-        if self.settings.include_all:
+        if self.integration_config.include_all:
             raise ValueError("include_all:true is not supported for PynamoDB")
         return super().selected_projects()
 
-    def get_project(self, override_config: OverrideConfig) -> PynamodbProjectInfo:
-        """Given an project override configuration, return the project config"""
+    def get_project(self, project_config: ProjectConfig) -> PynamodbProjectInfo:
+        """Given a project config, return ProjectInfo object"""
 
-        override = copy.deepcopy(override_config)
+        copy_project_config = copy.deepcopy(project_config)
 
         project_full_path = construct_project_full_path(
-            self.root_dir, override.project_path
+            self.root_dir, copy_project_config.project_path
         )
 
-        override.artifact_path = override.artifact_path or self.APP_IDENTIFIERS
+        copy_project_config.artifact_path = (
+            copy_project_config.artifact_path or self.APP_IDENTIFIERS
+        )
+
+        copy_project_config.include_models = (
+            copy_project_config.include_models or self.integration_config.include_models
+        )
 
         project = PynamodbProjectInfo(
             org_name_snakecase=self.config.org_name_snakecase,
             root_path=self.root_dir,
-            override=override,
+            config=copy_project_config,
             full_path=project_full_path,
             artifact_full_path=None,
         )
@@ -212,9 +217,9 @@ class PynamodbDapiValidator(RuntimeDapiValidator[PynamodbProjectInfo]):
         """Build the datastores for the table"""
         return self.add_non_playbook_datastore_fields(
             construct_dapi_source_sink_from_playbooks(
-                project.override.playbooks, table_name
+                project.config.playbooks, table_name
             )
-            if project.override.playbooks
+            if project.config.playbooks
             else {"sources": [], "sinks": []}
         )
 
@@ -223,7 +228,7 @@ class PynamodbDapiValidator(RuntimeDapiValidator[PynamodbProjectInfo]):
         table_name = table["table_name"]
         service = table["service"].split(".")[0]
 
-        project_path = project.override.project_path
+        project_path = project.config.project_path
         project_path = project_path.replace("/", ".")
         project_path = (
             service if project.full_path == project.root_path else project_path
@@ -266,9 +271,7 @@ class PynamodbDapiValidator(RuntimeDapiValidator[PynamodbProjectInfo]):
         for table in project.tables:
             table_name = table["table_name"]
 
-            if not is_model_in_allowlist(
-                table_name, project.full_path, project.override.model_allowlist
-            ):
+            if not project.is_model_included(table_name, project.full_path):
                 continue
 
             entry = {
@@ -278,7 +281,7 @@ class PynamodbDapiValidator(RuntimeDapiValidator[PynamodbProjectInfo]):
                     {
                         "urn": self.build_urn_for_table(project, table),
                         "owner_team_urn": construct_owner_team_urn_from_playbooks(
-                            project.override.playbooks, table_name, project.full_path
+                            project.config.playbooks, table_name, project.full_path
                         ),
                         "datastores": self.build_datastores_for_table(
                             project, table_name
