@@ -12,7 +12,6 @@ import esprima.nodes as nd
 from opendapi.config import (
     construct_dapi_source_sink_from_playbooks,
     construct_owner_team_urn_from_playbooks,
-    is_model_in_allowlist,
 )
 from opendapi.models import PlaybookConfig
 from opendapi.validators.dapi.base.js import JsProjectsDapiValidatorBase
@@ -272,14 +271,12 @@ class SequelizeDapiValidator(JsProjectsDapiValidatorBase):
                     filename,
                     file_pkgs[filename],
                     self.config.org_name_snakecase,
-                    table_config.override.playbooks,
+                    table_config.config.playbooks,
                     project,
                     node,
                 )
 
-                if is_model_in_allowlist(
-                    table.name, table.filename, table_config.override.model_allowlist
-                ):
+                if table_config.is_model_included(table.name, table.filename):
                     tables.append(table)
 
             if self.is_class_extends_model_declaration(node):
@@ -311,16 +308,15 @@ class SequelizeDapiValidator(JsProjectsDapiValidatorBase):
                 model_class_filenames[class_name],
                 pkg_name,
                 self.config.org_name_snakecase,
-                table_config.override.playbooks,
+                table_config.config.playbooks,
                 project,
                 class_name,
                 model_class_nodes[class_name],
             )
 
-            if is_model_in_allowlist(
+            if table_config.is_model_included(
                 table.name,
                 table.filename,
-                table_config.override.model_allowlist,
             ):
                 tables.append(table)
         return tables
