@@ -12,16 +12,15 @@ from functools import cached_property
 from multiprocessing import Pipe, Process, connection
 from typing import TYPE_CHECKING, Dict, List, Optional
 
+from opendapi.adapters.file import find_files_with_suffix
 from opendapi.config import (
     construct_dapi_source_sink_from_playbooks,
     construct_owner_team_urn_from_playbooks,
     construct_project_full_path,
     get_project_path_from_full_path,
-    is_model_in_allowlist,
 )
 from opendapi.logging import logger
-from opendapi.models import OverrideConfig
-from opendapi.utils import find_files_with_suffix
+from opendapi.models import ProjectConfig
 from opendapi.validators.dapi.base.main import ORMIntegration
 from opendapi.validators.dapi.base.runtime import RuntimeDapiValidator
 from opendapi.validators.dapi.models import ProjectInfo
@@ -184,9 +183,9 @@ class SqlAlchemyDapiValidator(RuntimeDapiValidator[SqlAlchemyProjectInfo]):
         """Build the datastores for the table"""
         return self.add_non_playbook_datastore_fields(
             construct_dapi_source_sink_from_playbooks(
-                project.override.playbooks, table_name
+                project.config.playbooks, table_name
             )
-            if project.override.playbooks
+            if project.config.playbooks
             else {"sources": [], "sinks": []}
         )
 
@@ -197,27 +196,30 @@ class SqlAlchemyDapiValidator(RuntimeDapiValidator[SqlAlchemyProjectInfo]):
             f"{project.service_name}.{table_name}"
         )
 
-    def get_project(self, override_config: OverrideConfig) -> SqlAlchemyProjectInfo:
+    def get_project(self, project_config: ProjectConfig) -> SqlAlchemyProjectInfo:
         """Given an project override configuration, return the project config"""
 
-        override = copy.deepcopy(override_config)
+        copy_project_config = copy.deepcopy(project_config)
 
         project_full_path = construct_project_full_path(
-            self.root_dir, override.project_path
+            self.root_dir, copy_project_config.project_path
         )
 
-        if override.artifact_path is None:
+        if copy_project_config.artifact_path is None:
             raise ValueError("artifact_path is required in the configuration")
 
-        artifact_path, metadata = override.artifact_path.split(":")
+        artifact_path, metadata = copy_project_config.artifact_path.split(":")
         artifact_full_path = os.path.join(project_full_path, artifact_path)
 
-        override.artifact_path = artifact_path
+        copy_project_config.artifact_path = artifact_path
+        copy_project_config.include_models = (
+            copy_project_config.include_models or self.integration_config.include_models
+        )
 
         project = SqlAlchemyProjectInfo(
             org_name_snakecase=self.config.org_name_snakecase,
             root_path=self.root_dir,
-            override=override,
+            config=copy_project_config,
             full_path=project_full_path,
             artifact_full_path=artifact_full_path,
             metadata_variable=metadata,
@@ -235,7 +237,9 @@ class SqlAlchemyDapiValidator(RuntimeDapiValidator[SqlAlchemyProjectInfo]):
 
         artifacts = [
             x.strip()
-            for x in f"{self.settings.artifact_path or self.APP_IDENTIFIERS}".split(",")
+            for x in f"{self.integration_config.artifact_path or self.APP_IDENTIFIERS}".split(
+                ","
+            )
         ]
         projects = []
 
@@ -252,8 +256,10 @@ class SqlAlchemyDapiValidator(RuntimeDapiValidator[SqlAlchemyProjectInfo]):
                 artifact_path = get_project_path_from_full_path(base_dir, import_file)
                 artifact_path = f"{artifact_path}:{metadata}"
 
-                override = OverrideConfig(
-                    project_path=project_path, artifact_path=artifact_path
+                override = ProjectConfig(
+                    project_path=project_path,
+                    artifact_path=artifact_path,
+                    include_models=self.integration_config.include_models,
                 )
                 projects.append(self.get_project(override))
 
@@ -276,7 +282,7 @@ class SqlAlchemyDapiValidator(RuntimeDapiValidator[SqlAlchemyProjectInfo]):
 
             if not project.metadata_variable:
                 raise ValueError(
-                    f"artifact_path misconfiguration for {project.override.project_path}"
+                    f"artifact_path misconfiguration for {project.config.project_path}"
                 )
 
     def _get_dapis_for_project(self, project: SqlAlchemyProjectInfo) -> Dict[str, Dict]:
@@ -285,9 +291,7 @@ class SqlAlchemyDapiValidator(RuntimeDapiValidator[SqlAlchemyProjectInfo]):
 
         for table in project.tables:
 
-            if not is_model_in_allowlist(
-                table["name"], project.full_path, project.override.model_allowlist
-            ):
+            if not project.is_model_included(table["name"], project.full_path):
                 continue
 
             # Note this includes the schema as well
@@ -298,7 +302,7 @@ class SqlAlchemyDapiValidator(RuntimeDapiValidator[SqlAlchemyProjectInfo]):
                     {
                         "urn": self.build_urn_for_table(project, table_full_name),
                         "owner_team_urn": construct_owner_team_urn_from_playbooks(
-                            project.override.playbooks,
+                            project.config.playbooks,
                             table_full_name,
                             project.full_path,
                         ),
