@@ -35,7 +35,6 @@ from pyparsing import (
 from opendapi.config import (
     construct_dapi_source_sink_from_playbooks,
     construct_owner_team_urn_from_playbooks,
-    is_model_in_allowlist,
 )
 from opendapi.validators.dapi.base.js import JsProjectsDapiValidatorBase
 from opendapi.validators.dapi.base.main import ORMIntegration
@@ -322,10 +321,9 @@ class Table:
     @property
     def is_in_allowlist(self) -> bool:
         """Return whether the table is in the allowlist"""
-        return is_model_in_allowlist(
+        return self.project.is_model_included(
             self.name,
             self.filename,
-            self.project.override.model_allowlist,
         )
 
     @classmethod
@@ -404,7 +402,7 @@ class Table:
 
     def construct_datastores(self) -> List[str]:
         """Get the datastores for the table."""
-        playbooks = self.project.override.playbooks
+        playbooks = self.project.config.playbooks
         return JsProjectsDapiValidatorBase.add_non_playbook_datastore_fields(
             construct_dapi_source_sink_from_playbooks(playbooks, self.name)
             if playbooks
@@ -413,7 +411,7 @@ class Table:
 
     def construct_team_urn(self) -> OptionalType[str]:
         """Construct the team URN for the table."""
-        playbooks = self.project.override.playbooks
+        playbooks = self.project.config.playbooks
         return (
             construct_owner_team_urn_from_playbooks(playbooks, self.name, self.filename)
             if playbooks
